(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    158136,       3022]*)
(*NotebookOutlinePosition[    162407,       3117]*)
(*  CellTagsIndexPosition[    161685,       3101]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["PolygonTriangulation`SimplePolygonTriangulation`", "Subsection"],

Cell[TextData[{
  "Polygons without self\[Dash]intersections or holes are called `simple'. (A \
simple polygon may be convex or concave.) The triangulation of simple \
polygons, i.e. their decomposition into triangles, is a well explored problem \
in computational geometry. This package provides functions for triangulating \
simple polygons defined in two dimensions or embedded in three dimensions. \
Non\[Dash]simple polygons are handled by the ",
  StyleBox["PolygonTessellation ", "MR"],
  "package."
}], "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["SimplePolygonTriangulation",
                      "MR"], 
                    StyleBox["[",
                      "MR"], 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{
                            StyleBox["{",
                              "MR"], 
                            RowBox[{
                              SubscriptBox[
                                StyleBox["x",
                                  "MR"], "1"], ",", \(y\_1\)}], "}"}], 
                          ",", \({x\_2, y\_2}\), ",", "\[Ellipsis]"}], "}"}],
                      "InlineFormula"], "]"}], 
                  RowBox[{"compute", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "triangulation", " ", "of", 
                    " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "simple", " ", "polygon"}]},
                {
                  RowBox[{
                    StyleBox["SimplePolygonTriangulation3D",
                      "MR"], 
                    StyleBox["[",
                      "MR"], 
                    RowBox[{
                      StyleBox["{",
                        "InlineFormula"], 
                      RowBox[{
                        RowBox[{
                          StyleBox["{",
                            "MR"], 
                          RowBox[{
                            StyleBox[
                              SubscriptBox[
                                StyleBox["x",
                                  "MR"], "1"],
                              "InlineFormula"], 
                            StyleBox[",",
                              "InlineFormula"], 
                            StyleBox[\(y\_1\),
                              "InlineFormula"], 
                            StyleBox[",",
                              "InlineFormula"], 
                            SubscriptBox[
                              StyleBox["z",
                                "InlineFormula"], "1"]}], 
                          StyleBox["}",
                            "InlineFormula"]}], 
                        StyleBox[",",
                          "InlineFormula"], 
                        RowBox[{
                          StyleBox["{",
                            "InlineFormula"], 
                          RowBox[{
                            StyleBox[\(x\_2\),
                              "InlineFormula"], 
                            StyleBox[",",
                              "InlineFormula"], 
                            StyleBox[\(y\_2\),
                              "InlineFormula"], 
                            StyleBox[",",
                              "InlineFormula"], 
                            SubscriptBox[
                              StyleBox["z",
                                "InlineFormula"], "2"]}], 
                          StyleBox["}",
                            "InlineFormula"]}], 
                        StyleBox[",",
                          "InlineFormula"], 
                        StyleBox["\[Ellipsis]",
                          "InlineFormula"]}], 
                      StyleBox["}",
                        "InlineFormula"]}], 
                    StyleBox["]",
                      "MR"]}], 
                  RowBox[{"compute", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "triangulation", " ", "of", 
                    " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "simple", " ", "polygon", " ",
                     "embedded", " ", "in", " ", "three", " ", 
                    "dimensions"}]},
                {
                  RowBox[{
                    StyleBox["TriangulateSimplePolygons",
                      "MR"], 
                    StyleBox["[",
                      "MR"], 
                    StyleBox["expr",
                      "TI"], 
                    StyleBox["]",
                      "MR"]}], 
                  RowBox[{
                  "triangulate", " ", "all", " ", "two\[Dash]dimensional", 
                    " ", "polygons", " ", "in", " ", 
                    StyleBox["expr",
                      "TI"], " "}]},
                {
                  RowBox[{
                    StyleBox["TriangulateSimplePolygons3D",
                      "MR"], 
                    StyleBox["[",
                      "MR"], 
                    StyleBox["expr",
                      "TI"], 
                    StyleBox["]",
                      "MR"]}], 
                  RowBox[{
                  "triangulate", " ", "all", " ", "three\[Dash]dimensional", 
                    " ", "polygons", " ", "in", " ", 
                    StyleBox["expr",
                      "TI"]}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{
  "SimplePolygonTriangulation:SimplePolygonTriangulation", 
    "SimplePolygonTriangulation:SimplePolygonTriangulation3D", 
    "SimplePolygonTriangulation:TriangulateSimplePolygons", 
    "SimplePolygonTriangulation:TriangulateSimplePolygons3D"}],

Cell["Simple polygon triangulation functions. ", "Caption"],

Cell[TextData[{
  "The triangulation returned by ",
  StyleBox["SimplePolygonTriangulation", "MR"],
  " and ",
  StyleBox["SimplePolygonTriangulation3D", "MR"],
  " is a list of triples of point indices. Each triple of points represents \
one of the triangles of the triangulation."
}], "Text"],

Cell["This loads the package.", "MathCaption"],

Cell[BoxData[
    \(<< PolygonTriangulation`SimplePolygonTriangulation`\)], "Input",
  CellLabel->"In[1]:= "],

Cell["Here is a list of points in the plane.", "MathCaption"],

Cell[BoxData[
    \(data2D = {{4.4, 14}, {6.7, 15.25}, {6.9, 12.8}, {9.5, 14.9}, {13.2, 
          11.9}, {10.3, 12.3}, {6.8, 9.5}, {13.3, 7.7}, {0.6, 1.1}, {1.3, 
          2.4}, {2.45, 4.7}}; \)], "Input",
  CellLabel->"In[2]:= "],

Cell["They represent a simple polygon, which is concave.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics[Polygon[data2D]]]\)], "Input",
  CellLabel->"In[3]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0211849 0.0749906 -0.0310421 0.0415974 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.30877 .55132 m
.48125 .60332 L
.49625 .50141 L
.69123 .58876 L
.96869 .46397 L
.75122 .48061 L
.48875 .36413 L
.97619 .28926 L
.02381 .01472 L
.0763 .06879 L
.16254 .16447 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53J`00?g=cLda<C2LW9b40<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7iYW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`c
olaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lco
I/coVLcoc<coool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI
0?nI<onII_nIVOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<ool78@L00?l78@L00?l78@L00?l78@L00?l7
8@L000P70`3o1aH700091`D0o`LC1`002PL80?l73`L000/72P3o1``7000<1`d0o`L81`003@L?0?l7
1@L000h74P3o1`47000?1a@0o@L001075`3i1`004@LI0?H7000B1a`0lPL001<77P3_1`0050LQ0>/7
000E1b<0j0L001H79P3T1`005`LX0>47000H1b/0g@L001T7;@3J1`006PL`0=H7000K1c80d`L001`7
=@3?1`0070Lh0<`7000M1c/0b0L001h7?@351`007`M00<47000P1d80_PL00247A@2j1`008PM70;L7
000R1d/0/`L002<7C@2`1`0090M@0:`7000U1e80Z@L002H7E@2U1`009`MG0:87000X1eX0WPL002P7
G@2K1`00:@MP09L7000Z1f80U0L002/7I02A1`00;0MW08d7000]1fT0RPL002h7K0261`00;PM_08<7
000_1g80O`L002l7M@1l1`00<0Mh07P7000`1g/0M@L00307O`1a1`00<@N106h7000a1hD0JPL00387
Q`1W1`00<PN;06<7000b1hh0H0L003<7T@1L1`00<`ND05T7000c1iP0E@L003@7VP1B1`00=0NN04h7
000e1j00B`L003D7Y0171`00=@NW04@7000f1jX0@0L003H7[@0m1`00=`N`03T7000g1k<0=PL003L7
]`0b1`00>0Ni02l7000h1kd0:`L003P7`00X1`00>@O302@7000i1lH08@L003X7b@0M1`00>PO<01X7
000j1m005PL003/7dP0C1`00>`OF00l7000k1mT030L003`7f`091`00?0OE00l7000m1lh05@L003d7
b00K1`00?@O10287000n1kX0:0L003h7]00^1`00?`N/03D7000o1jH0>`L003l7X0111`00@0NH04P7
00101i80CPL00407S01D1`00@@N405/700111gh0H@L00487M`1W1`00@PM`06h700121fX0M0L004<7
H`1j1`00@`ML084700131eH0Q`L004@7C`2=1`00A0M809@700151dX0T@L004D7C02?1`00A@M>08d7
00161e00RPL004H7DP281`00A`MC08H700171eD0Q0L004L7F0211`00B0MI07l700181e/0O@L004P7
G@1k1`00B@MO07P700191f40MPL004X7HP1d1`00BPMU0747001:1fL0K`L004/7J01]1`00B`MZ06/7
001<1f`0J0L004`7KP1V1`00C0M`06@7001=1g40HPL004d7M01O1`00C@Mf05d7001>1gL0F`L004h7
NP1H1`00C`Mk05H7001?1gd0E0L004l7O`0k1`X03@L00507P@0/1a@03`L00507P`0M1al04@L00507
Q@0?1bT04`L00547^P0E1`00D@Ng01P7001B1k@06PL00587/P0L1`00DPN`01h7001C1jd080L005<7
ZP0S1`00E0Lj00<7JP0U1`00E0Lj00D7IP0W1`00E0Lj00L7HP0Y1`00E@Li00T7GP0[1`00E@Li00`7
F00^1`00E@Li00h7E00`1`00EPLh0107D00b1`00EPLg01<7C00d1`00E`Lf01H7A`0f1`00E`Lf01P7
@P0i1`00E`Lf01X7?P0k1`00F0Le01`7>P0m1`00F0Le01l7=@0o1`00F0Le0247<@111`00G0L`02@7
;0141`00G`L]02H7:0161`00HPLZ02T78`181`00IPLV02/77`1:1`00J@LS02d76`1<1`00K0LP02l7
5P1?1`00L0LL03874@1A1`00L`LH03D73@1C1`00MPLE03L72@1E1`00NPLA03T71@1G1`00O@L>09D7
00201`/0U@L008@71`2E1`00Q`L409D7003o1b47003o1b47003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.265962, 0.746177, \
0.0465787, 0.0839707}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[3]= "]
}, Open  ]],

Cell["This gives the triangulation.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(triang = SimplePolygonTriangulation[data2D]\)], "Input",
  CellLabel->"In[4]:= "],

Cell[BoxData[
    \({{6, 3, 4}, {5, 6, 4}, {1, 2, 3}, {3, 6, 7}, {1, 3, 7}, {1, 7, 11}, {7, 
        8, 11}, {10, 11, 8}, {9, 10, 8}}\)], "Output",
  CellLabel->"Out[4]= "]
}, Open  ]],

Cell["This replaces the indices by the corresponding points.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(triangPoints = Map[Part[data2D, #] &, triang]\)], "Input",
  CellLabel->"In[5]:= "],

Cell[BoxData[
    \({{{10.3`, 12.3`}, {6.9`, 12.8`}, {9.5`, 14.9`}}, {{13.2`, 
          11.9`}, {10.3`, 12.3`}, {9.5`, 14.9`}}, {{4.4`, 14}, {6.7`, 
          15.25`}, {6.9`, 12.8`}}, {{6.9`, 12.8`}, {10.3`, 12.3`}, {6.8`, 
          9.5`}}, {{4.4`, 14}, {6.9`, 12.8`}, {6.8`, 9.5`}}, {{4.4`, 
          14}, {6.8`, 9.5`}, {2.45`, 4.7`}}, {{6.8`, 9.5`}, {13.3`, 
          7.7`}, {2.45`, 4.7`}}, {{1.3`, 2.4`}, {2.45`, 4.7`}, {13.3`, 
          7.7`}}, {{0.6`, 1.1`}, {1.3`, 2.4`}, {13.3`, 7.7`}}}\)], "Output",
  CellLabel->"Out[5]= "]
}, Open  ]],

Cell["The triangles cover the whole polygon.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      Graphics[Map[{Hue[Random[]], Polygon[#]} &, triangPoints]]]\)], "Input",\

  CellLabel->"In[6]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0716076 0.0147151 0.038597 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 .137 1 r
.76137 .48946 m
.5179 .50876 L
.70408 .58981 L
F
1 0 .689 r
.96903 .47402 m
.76137 .48946 L
.70408 .58981 L
F
0 .126 1 r
.33888 .55507 m
.50358 .60332 L
.5179 .50876 L
F
.116 1 0 r
.5179 .50876 m
.76137 .48946 L
.51074 .38139 L
F
0 1 .674 r
.33888 .55507 m
.5179 .50876 L
.51074 .38139 L
F
1 0 .983 r
.33888 .55507 m
.51074 .38139 L
.19925 .19612 L
F
1 .193 0 r
.51074 .38139 m
.97619 .31191 L
.19925 .19612 L
F
.222 0 1 r
.1169 .10735 m
.19925 .19612 L
.97619 .31191 L
F
.483 0 1 r
.06677 .05717 m
.1169 .10735 L
.97619 .31191 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53J`00?g=cLda<C2LW9b40<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7iYW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`c
olaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lco
I/coVLcoc<coool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI
0?nI<onII_nIVOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<ool78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L001@70fWo1`X7000E1`IYo`L61`005PL8JOl70`L001L72fWn1`0060L=JO/7
000I1a1Ym`L001X74VWd1`006`LEJO07000L1aQYk0L001d76VWY1`007PLMJND7000O1amYhPL00207
8VWN1`008@LTJM/7000R1`041504D2=Ye`L002<71e0RJM@7000T1`0:1504D0A@1504D29Yd0L002D7
3E0RJL`7000V1`0@1504D0A@1504D0A@1504D25Yb@L002L7550PJLD7000X1`0G1504D0A@1504D0A@
1504D0A@1504D0@07fW21`00:@LJD1mY_PL002X701d4D0A@1504D0A@1504D0A@1504D0A@1504D0A@
100NJK/7000[1b1@7VVg1`00;0L08`A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@150401iY
/`L002d79e0LJK07000]1`0[D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504
D00LJJ`7000^1bi@6fVY1`00;`L0<E04D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504
D0A@1504D0A@15006fVU1`00<0LdD1YYXPL0034703M@1504D0A@1504D0A@1504D0A@1504D0A@1504
D0A@1504D0A@1504D0A@1504D0A@1504D0A@01YYWPL00387>e0HJI/7000c1`0nD0A@1504D0A@1504
D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0@HJIL7000d1d5@
66VC1`00=@L0A504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504
D0A@1504D0A@1504D0A@15045fV@1`00=PM7D1MYS0L003L704Y@1504D0A@1504D0A@1504D0A@1504
D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@11IYR@L003P7
CU0EJHD7000i1`1AD0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504
D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@01AYPPL003T7EE0DJGh7000j1`1H1IX1VP6J
1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@
1504D0A@1504D0A@1504D0A@1504D1AYNPL003X70`D:VTm@4fUg1`00>`L41@1KVP6J0IX1VP6J0IX1
VP6J1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504
D0A@1504D0A@1504D0A@1504D00CJG<7000k1`D559Y;D15YL0L003/71`D0H@6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP5@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@
1504D0A@1504D0A@1504D0A@1504D0@04FU/1`00?0L81AjJAE0@JFT7000l1`T506JJ0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP5@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504
D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0@@JFD7000m1`X5:9Y0D0mYHPL003d730D0JYX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VPA@1504D0A@1504D0A@1504
D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0@?JEh7000m1`d5<iXkD0iY
FPL003h73PD0L06J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP5@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@
150=JEL7000n1a05?9XfD0eYD`L003l740D0MIX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0E04D0A@1504D0A@1504D0A@1504D0A@1504
D0A@1504D0A@1504D0A@1504D0A@1504D00<JE07000o1a85AiX`D0aYC0L003l750D0NIX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VPA@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504D0A@15002fU91`00
@0LD1E6J;50:JDD700101aH507l1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VPA@1504D0A@1504D0A@
1504D0A@1504D0A@1504D0A@1504D0A@150400YY@@L004475`EKVRI@2FTn1`00@@LH1@24VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1D0A@1504D0A@1504D0A@1504D0A@1504D0A@1504
D0A@15042FTj1`00@@LJ1FFJ8E08JCL700121a/508RJ0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1D0A@1504D0A@1504D0A@1504D0A@1504D0A@150426Tc1`00@PLL1FnJ
7E06JC0700131ad508h1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VPA@1504D0A@1504D0A@1504D0A@1504D0A@1VT/1`00@`LO1GVJ5e05JBT700131b05
09>J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J1504D0A@1504D0A@1504D0A@15001FTU1`00A0LQ1H>J4U05JB4700141b<509NJ0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1D0A@1504D0A@1504D0A@00AY7PL004@79@F=VPe@0fTJ1`00A@LU1@2M0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1D0A@1504D0A@1002JAL700151bL5UiX8D09Y4`L004H7:0D0XP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VPA@1504JA0700161bT5XYX2D003J@L700X7
00161b/50:JJ0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX12@L004L7
;0FNVPl700171bd509H1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IXF1`00B0L^1HjJ70L004P7
<0D0Q@6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP408`L004P7<@EmVRX700191c8507FJ0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX0<0L004T7=0E/VSL7001:1c@506@1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J?PL004X7=PELVT@7001:1cP505<1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J
0IX1VP6J0IX1VP6J0IX1VP6J0@1;1`00B`Lh1D^JDPL004/7>PD0@iX1VP6J0IX1VP6J0IX1VP6J0IX1
VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX0F0L004`7>`DjVUl7
001<1c`50381VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VVH7
001<1ch5:YY/1`00C@Lo1@0Q0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX1VP6J0IX107<7001=1d05
6IYj1`00C@M21@0AVP6J0IX1VP6J0IX1VP6J0IX0P0L004h7@`D8VXL7001>1d@5SPL004l7@PD2B`03
0V0708X7001?1d4500=:BdX010:91`00C`M01@A;00H2H09P0V271`00D0Ln1@05BT]:BdX02@:41`00
D0Lm1@I;00/2H09P0V02H09P0P221`00D@Lk1@07BT]:BdY;BP0=0X07001A1cX524/0409P0V02H09P
0V02H09P0V1m1`00D@Li1@09BT]:BdY;BT]:0182N`L00587=`D:B`0D0V02H09P0V02H09P0V02H09P
0V1i1`00DPLf1@0;BT]:BdY;BT]:BdX05`9f1`00D`Ld1@a;01T2H09P0V02H09P0V02H09P0V02H09P
0V0207@7001C1c<500e:BdY;BT]:BdY;BT]:01/2LPL005<7<PD>B`0N0V02H09P0V02H09P0V02H09P
0V02H09P0V02H09PK`L005@7<0D03dY;BT]:BdY;BT]:BdY;BP0P0Vd7001D1bl544/08P9P0V02H09P
0V02H09P0V02H09P0V02H09P0V02H09P0V1[1`00E@L]1@0ABT]:BdY;BT]:BdY;BT]:BdX09@9X1`00
E@L/1A9;02L2H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H080IPL005D7:`D04dY;
BT]:BdY;BT]:BdY;BT]:BdX0:@9T1`00EPLY1AE;02]P0V02H09P0V02H09P0V02H09P0V02H09P0V02
H09P0V02H09P0V02H09P0647001F1bP501I:BdY;BT]:BdY;BT]:BdY;BT]:BdY;;@9O1`00E`LV1AM;
02mP0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H01M1`00E`LU1@0H
BT]:BdY;BT]:BdY;BT]:BdY;BT]:BdY;<P9J1`00E`LT1AU;03AP0V02H09P0V02H09P0V02H09P0V02
H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02F0L005P78PD06TY;BT]:BdY;BT]:BdY;BT]:BdY;
BT]:BdY;=P9F1`00F0LQ1A];03UP0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02
H09P0V02H09P0V02H09P0V00D`L005P780D074Y;BT]:BdY;BT]:BdY;BT]:BdY;BT]:BdY;BT/k0U47
001I1ah57D/0?F02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02
H09P0V02H09P0V00>@L9V@d7001I1ad501i:BdY;BT]:BdY;BT]:BdY;BT]:BdY;BT]:BdY;BT]00RX7
01>HVIRIV9VHVIRIV9VHVIRIV9VH00l7001J1a/57d/0@V02H09P0V02H09P0V02H09P0V02H09P0V02
H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0Q`77ITA1`00FPLJ1@0PBT]:BdY;
BT]:BdY;BT]:BdY;BT]:BdY;BT]:BdY;BT]40Ph702JHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRI
V9VHVIRIV9VHVA@7001J1aT58D/0AV02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02
H09P0V02H09P0V02H09P0V02H09P0V02H09P0V02H08`VAH7001K1aL5029:BdY;BT]:BdY;BT]:BdY;
BT]:BdY;BT]:BdY;BT]:BdY;>080?0@n13h4?P@n13h4?P@nV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRI
V9VHVIRIV9VHVIRIV9VHVIRIV9VHVAP7001K1aH58d/0AF02H09P0V02H09P0V02H09P0V02H09P0V02
H09P0V02H09P0V02H09P0Sh4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P0/VA/7001L1a@502A:BdY;
BT]:BdY;BT]:BdY;BT]:BdY;BT]:BdY;BT]:BdY;BT/L0P1C13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h4?P@n13h4?P@n13h4?PBIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIP0
7@L005`74`DUB`14H09P0V02H09P0V02H08n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4
?P@n13h4?P@n13h4?P@n13h4?P@YVAl7001L1a85091:BdY;BT]:BdY;BT]:BdY;BT]:BdY;BT]:BdY;
BT]:BdY;BT]:B`@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h4?P@n13h4?P@n13h4?PBIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9TR1`00
G@L@1BA;00<4?P@00`L0@0@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h4?P@n13h4?P@n13h4?P@n13hUVB@7001M1`l502Q:BdY;BT]:BdY;BT]:BdY;BT]:BdY;BT]:BdY;
BT]:BdXn13h4?P@n1@L0HCh4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4
?P@n13h4?P@n13h4?P@n13jHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9T09PL005h7
3@DNB`0;13h4?P@n13h4?P@01`L0>`@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h4?P@n13h4?P@n13h4?P@n13h402:I:0L005h730D0:TY;BT]:BdY;BT]:BdY;BT]:BdY;BT]:BdY;
BSh4?P@n13h4?P@n13h4?PX705L4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h4?P@n13h4?P@n13h4VIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIP0:`L005h72`DHB`0C
13h4?P@n13h4?P@n13h4?P@n100<1`0d?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4
?P@n13h4?P@n13h4?P@n11nI;@L005l72@D0;4Y;BT]:BdY;BT]:BdY;BT]:BdY;BSh4?P@n13h4?P@n
13h4?P@n13h4?P@n3PL0C`@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h4?P@nV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIRIV9VHVIP0;`L005l720DBB`0J13h4?P@n13h4?P@n
13h4?P@n13h4?P@n13hB1`0^13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h4?Q^I<PL006071PD0;DY;BT]:BdY;BT]:BdY;BSh4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
100D1`15?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?PBIV9VHVIRIV9VH
VIRIV9VHVIRIV9VHVIRI03@7001P1`D534/08P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13hF1`0Y13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@069Tf1`00H0L41@0_
BT]:BdY;BT]:?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@06@L0>`@n13h4?P@n
13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?PBIV9VHVIRIV9VHVIRIV9VHVIRIV9VH03T7001Q1`85
1T/0:P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?Q/702<n13h4?P@n13h4
?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P0DVC/7001Q1`0b1DY;BSh4?P@n13h4?P@n13h4?P@n13h4
?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@M1`0c13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13jHVIRIV9VHVIRIV9VHVIRIV9VH03d7001Q1`0b13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h4?P@n13h4?P@n13h4?P@n13hO1`0N?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h44ITo1`00
I@L0;Ch4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P0S1`0Y?P@n13h4
?P@n13h4?P@n13h4?P@n13h4?PBIV9VHVIRIV9VHVIRIV9T0@PL006P702Xn13h4?P@n13h4?P@n13h4
?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@U1`0G13h4?P@n13h4?P@n13h4?P@n13h4?P@03YU41`00
K0L09P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n9`L08Ch4?P@n13h4?P@n13h4
?P@n13h4?YRIV9VHVIRIV9VHV@161`00K`L08`@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h402X7014n13h4?P@n13h4?P@n13h4?P0:VDT7001b1`0P13h4?P@n13h4?P@n13h4?P@n13h4?P@n
13h4?P@n13h/1`0G13h4?P@n13h4?P@n13h4VIRIV9VHVIP0B`L007H701`n13h4?P@n13h4?P@n13h4
?P@n13h4?P@n13h4;PL033h4?P@n13h4?P@n10NIC@L007T701Tn13h4?P@n13h4?P@n13h4?P@n13h4
?P@n034700dn13h4?P@n19VHVIRI0507001l1`0E?P@n13h4?P@n13h4?P@n13h4?P@n03@700H4?P@n
13h3VE8700201`0A13h4?P@n13h4?P@n13h4?P@0=PL01Ch4?YRI05@700231`0>13h4?P@n13h4?P@n
13j?1`00QPL02`@n13h4?P@n13h408l7002:1`07?P@n13h4?P2?1`00S@L013h4?PB?1`00o`LQ1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.349819, -0.38133, \
0.0487792, 0.0904983}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[6]= "]
}, Open  ]],

Cell[TextData[{
  "This triangulates a ",
  StyleBox["Polygon", "MR"],
  " primitive within a ",
  StyleBox["Graphics", "MR"],
  " object. As all triangles are black, the result cannot be distinguished \
from the original polygon."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(triangGraph = 
      Show[TriangulateSimplePolygons[Graphics[Polygon[data2D]]]]\)], "Input",
  CellLabel->"In[7]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0716076 0.0147151 0.038597 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.76137 .48946 m
.5179 .50876 L
.70408 .58981 L
F
.96903 .47402 m
.76137 .48946 L
.70408 .58981 L
F
.33888 .55507 m
.50358 .60332 L
.5179 .50876 L
F
.5179 .50876 m
.76137 .48946 L
.51074 .38139 L
F
.33888 .55507 m
.5179 .50876 L
.51074 .38139 L
F
.33888 .55507 m
.51074 .38139 L
.19925 .19612 L
F
.51074 .38139 m
.97619 .31191 L
.19925 .19612 L
F
.1169 .10735 m
.19925 .19612 L
.97619 .31191 L
F
.06677 .05717 m
.1169 .10735 L
.97619 .31191 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53J`00?g=cLda<C2LW9b40<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7iYW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`c
olaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lco
I/coVLcoc<coool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI
0?nI<onII_nIVOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<ool78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L001@70`3o1`X7000E1`H0o`L61`005PL80?l70`L001L72`3n1`0060L=0?/7
000I1a00m`L001X74P3d1`006`LE0?07000L1aP0k0L001d76P3Y1`007PLM0>D7000O1al0hPL00207
8P3N1`008@LT0=/7000R1bL0e`L002<7:@3D1`0090L/0=07000U1bl0c0L002H7<@391`009`Ld0<D7
000X1cH0`PL002T7>@2n1`00:PLk0;/7000[1ch0]`L002`7@@2c1`00;@M30;07000]1dL0[0L002h7
B@2Y1`00;`M<0:D7000`1dh0XPL00347D@2N1`00<PMC09/7000c1eH0U`L003@7F@2C1`00=@MK0907
000f1eh0S0L003L7H0291`00>0MS08D7000i1fD0PPL003T7J@1n1`00>PM/07X7000j1fl0M`L003/7
LP1c1`00>`Me0707000k1gT0K0L003`7N`1Y1`00?0Mo06D7000m1h40HPL003d7Q@1N1`00?@N905X7
000n1h/0E`L003h7S`1C1`00?`NA0507000o1iD0C0L003l7V0191`00@0NK04D700101il0@@L00447
X@0n1`00@@NU03X700111jP0=`L00487Z`0c1`00@PN^030700131k40;0L004<7]00Y1`00@`Nh02D7
00141k/08@L004@7_P0N1`00A0O201X700151l@05`L004D7b00C1`00APO:010700161lh030L004H7
d@091`00A`O:00l700171l<05PL004P7_00L1`00B0Ne02<700181jh0:PL004T7Y`0`1`00B@NP03L7
001:1iP0?PL004X7TP141`00BPN;04/7001;1h<0DPL004/7O@1H1`00C0Me05l7001<1fh0IPL004`7
J01/1`00C@MP07<7001=1eT0NPL004d7D`201`00CPM;08L7001>1d@0SPL004l7AP2;1`00C`M808T7
001?1dX0Q`L00507C0241`00D0M>0887001A1dl0P0L00547DP1m1`00D@MD07/7001B1eD0N@L00587
F01f1`00D`MI07@7001C1e/0LPL005<7GP1_1`00E0MO06d7001D1f40J`L005D7H`1X1`00E@MU06H7
001E1fL0I0L005H7J@1Q1`00EPM[05l7001G1f`0G@L005L7K`1J1`00E`Ma05P7001H1g80EPL005P7
M@1C1`00F0Mg0547001I1gP0>@L900d7001I1g/0:PLC00l7001J1g`070LM0147001J1gh03PLV01@7
001J1k005PL005/7[@0H1`00F`NZ01/7001L1jL07@L005`7Y@0O1`00G0NR0287001M1cL00`MU02@7
001M1cL01@MQ02H7001N1cH01`MM02P7001N1cH02PMG02/7001N1cH030MC02d7001O1cD03PM?02l7
001O1c@04PM90387001P1c<050M503@7001P1c<05PM103H7001P1c<06@Lk03T7001Q1c806`Lg03/7
001Q1c807@Lc03d7001Q1c807`L_03l7001U1bd08`LY0487001X1bX09@LU04@7001/1bH09`LQ04H7
001_1b<0:PLK04T7001b1b00;0LG04/7001f1a`0;PLC04d7001i1aT0<@L=0507001l1aD0=0L90587
00201a40=PL505@700231`h0S`L008H72`2?1`00RPL708l7002=1`@0S`L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.349819, -0.38133, \
0.0487792, 0.0904983}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[7]= "]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["InputForm", "MR"],
  " reveals the triangles."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(triangGraph // InputForm\)], "Input",
  CellLabel->"In[8]:= "],

Cell["\<\
Graphics[{Polygon[{{10.3, 12.3}, {6.9, 12.8}, {9.5, 14.9}}], 
  Polygon[{{13.2, 11.9}, {10.3, 12.3}, {9.5, 14.9}}], 
  Polygon[{{4.4, 14}, {6.7, 15.25}, {6.9, 12.8}}], 
  Polygon[{{6.9, 12.8}, {10.3, 12.3}, {6.8, 9.5}}], 
  Polygon[{{4.4, 14}, {6.9, 12.8}, {6.8, 9.5}}], 
  Polygon[{{4.4, 14}, {6.8, 9.5}, {2.45, 4.7}}], 
  Polygon[{{6.8, 9.5}, {13.3, 7.7}, {2.45, 4.7}}], 
  Polygon[{{1.3, 2.4}, {2.45, 4.7}, {13.3, 7.7}}], 
  Polygon[{{0.6, 1.1}, {1.3, 2.4}, {13.3, 7.7}}]}]\
\>", "Output",
  CellLabel->"Out[8]//InputForm= "]
}, Open  ]],

Cell[TextData[{
  "Simple polygons embedded in three dimensions can  be triangulated \
similarily with ",
  StyleBox["SimplePolygonTriangulation3D", "MR"],
  " and ",
  StyleBox["TriangulateSimplePolygons3D", "MR"],
  ". "
}], "Text"],

Cell[TextData[{
  "Here is a list of three-dimensional points having the same ",
  StyleBox["x", "IT"],
  ", ",
  StyleBox["y", "IT"],
  " coordinates as ",
  StyleBox["data2D", "MR"],
  "."
}], "MathCaption"],

Cell[BoxData[
    \(data3D = 
      Map[Append[#, 0.3*\((#[\([\)\(1\)\(]\)] + #[\([\)\(2\)\(]\)])\)] &, 
        data2D]; \)], "Input",
  CellLabel->"In[9]:= "],

Cell["\<\
They form a simple polygon embedded in three-dimensions. This \
polygon is concave and flat.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics3D[Polygon[data3D]]]\)], "Input",
  CellLabel->"In[10]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89493 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05629 -0.0303745 1.05629 [
[ 0 0 0 0 ]
[ 1 .89493 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04625 .24369 m
0 .55333 L
s
0 .55333 m
.42216 .89493 L
s
.42216 .89493 m
.42982 .61473 L
s
.42982 .61473 m
.04625 .24369 L
s
.66098 0 m
.96273 .45205 L
s
.96273 .45205 m
1 .74656 L
s
1 .74656 m
.67535 .32267 L
s
.67535 .32267 m
.66098 0 L
s
.04625 .24369 m
0 .55333 L
s
0 .55333 m
.67535 .32267 L
s
.67535 .32267 m
.66098 0 L
s
.66098 0 m
.04625 .24369 L
s
.42982 .61473 m
.96273 .45205 L
s
.96273 .45205 m
1 .74656 L
s
1 .74656 m
.42216 .89493 L
s
.42216 .89493 m
.42982 .61473 L
s
0 0 m
1 0 L
1 .89493 L
0 .89493 L
closepath
clip
newpath
.5 Mabswid
.13505 .30638 m .2456 .39448 L .55304 .72962 L p .546 .62 .877 r
F P
0 g
s
.06943 .25591 m .13505 .30638 L p .55304 .72962 L .546 .62 .877 r
F P
0 g
s
.82415 .48698 m .06943 .25591 L p .55304 .72962 L .546 .62 .877 r
F P
0 g
s
.55322 .56974 m .82415 .48698 L p .55304 .72962 L .546 .62 .877 r
F P
0 g
s
.77716 .67157 m .55322 .56974 L p .55304 .72962 L .546 .62 .877 r
F P
0 g
s
.91083 .6561 m .77716 .67157 L p .55304 .72962 L .546 .62 .877 r
F P
0 g
s
.79458 .76391 m .91083 .6561 L p .55304 .72962 L .546 .62 .877 r
F P
0 g
s
.63309 .68941 m .79458 .76391 L p .55304 .72962 L .546 .62 .877 r
F P
0 g
s
.55304 .72962 m .67724 .77308 L .63309 .68941 L p .546 .62 .877 r
F P
0 g
s
.25 Mabswid
.66098 0 m
.96273 .45205 L
s
.96273 .45205 m
1 .74656 L
s
1 .74656 m
.67535 .32267 L
s
.67535 .32267 m
.66098 0 L
s
.04625 .24369 m
0 .55333 L
s
0 .55333 m
.67535 .32267 L
s
.67535 .32267 m
.66098 0 L
s
.66098 0 m
.04625 .24369 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{288, 257.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00010@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53J`00?g=cLda<C2LW9b40<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7iYW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`c
olaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lco
I/coVLcoc<coool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI
0?nI<onII_nIVOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<ok`70P1R1`00^PL200031`000647002g1`<0
0`L20647002e1`801PL00`07001P1`00/PL300P700@01`L0G`L00;070P0;1`0400L705l7002]1`<0
3@L01@071`L005h7002[1`8040L00`071`021`0300L705/7002X1`<04PL00`071`021`0300L705/7
002V1`805@L00`071`031`0300L705X7002S1`<05`L00`071`041`0300L705T7002Q1`806PL00`07
1`041`0300L705T7002N1`<07@L00`071`041`0300L705P7002L1`8080L00`071`051`0300L705L7
002I1`<08PL00`071`051`0300L705L7002G1`809@L00`071`061`0300L705H7002D1`<09`L00`07
1`071`0300L705D7002A1`<0:PL00`071`071`0300L705D7002?1`80;@L00`071`081`0300L705@7
002<1`<0;`L00`071`091`0300L705<7002:1`80<PL00`071`091`0300L705<700271`<0=0L00`07
1`0:1`0300L7058700251`80=`L00`071`0;1`0300L7054700221`<0>@L00`071`0<1`0300L70507
00201`80?0L00`071`0<1`0300L70507001m1`<0?PL00`071`0=1`0300L704l7001k1`80@@L00`07
1`0>1`0300L704h7001h1`<0@`L00`071`0>1`0300L704h7001f1`80APL00`071`0?1`0300L704d7
001c1`<0B0L00`071`0@1`0300L704`7001a1`80B`L00`071`0@1`0300L704`7001^1`<0C@L00`07
1`0A1`0300L704/7001/1`80D0L00`071`0B1`0300L704X7001Y1`<0DPL00`071`0B1`0300L704X7
001W1`80E@L00`071`0C1`0300L704T7001T1`<0F0L00`071`0C1`0300L704P7001R1`80F`L00`07
1`0C1`0300L704P7001O1`<0G@L00`071`0D1`0300L704L7001M1`80H0L00`071`0E1`0300L704H7
001J1`<0HPL00`071`0E1`0300L704H7001H1`80I@L00`071`0F1`0300L704D7001E1`<0I`L00`07
1`0G1`0300L704@7001C1`80JPL00`071`0G1`0300L704@7001@1`<0K0L00`071`0H1`0300L704<7
001>1`80K`L00`071`0I1`0300L70487001;1`<0L@L00`071`0I1`0300L7048700191`80M0L00`07
1`0J1`0300L7044700161`<0MPL00`071`0K1`0300L7040700141`80N@L00`071`0K1`0300L70407
00111`<0N`L00`071`0L1`0300L703l7000o1`80OPL00`071`0M1`0300L703h7000l1`<0P0L00`07
1`0M1`0300L703h7000i1`<0P`L00`071`0N1`0300L703d7000g1`80QPL00`071`0O1`0300L703`7
000d1`<0R0L00`071`0O1`0300L703`7000b1`80R`L00`071`0P1`0300L703/7000_1`<0S@L00`07
1`0Q1`0300L703X7000]1`80T0L00`071`0Q1`0300L703X7000Z1`<0T`L00`071`0Q1`0300L703T7
000X1`80UPL00`071`0R1`0300L703P7000U1`<0V0L00`071`0R1`0300L703P7000S1`80V`L00`07
1`0S1`0300L703L7000P1`<0W@L00`071`0T1`0300L703H7000N1`80X0L00`071`0T1`0300L703H7
000K1`<0XPL00`071`0U1`0300L703D7000I1`80Y@L00`071`0V1`0300L703@7000F1`<0Y`L00`07
1`0W1`0300L703<7000D1`80ZPL00`071`0W1`0300L703<7000A1`<0[0L00`071`0X1`0300L70387
000?1`80[`L00`071`0Y1`0300L70347000=1`80/@L00`071`0Y1`0300L70347000=1`80/@L00`07
1`0Z1`0300L70307000=1`0300L00;0700<01`L0:`L00`071`0_1`003@L010071`031`80ZPL00`07
1`0[1`0300L702l7000<1`0300L7008700@01`L7102W1`0300L702`700<01`L0;PL000`700<01`L0
0`L01`071`L0N780102S1`0300L702d700<01`L0;@L000`700<01`L010L02P071`L0TG:ALY430:07
00<01`L0;@L00`071`0]1`0030L00`071`051`0300L7008700MhLWQbN79h00<0W@L00`071`0^1`03
00L702`7000<1`0300L700H700<01`L00PL02I5bTG:ALY5bT@0309X700<01`L0;`L00`071`0[1`00
30L00`071`071`0300L7008700]hLWQbN79hLWQbN00409H700<01`L0;`L00`071`0[1`0030L00`07
1`081`0300L7008700jALY5bTG:ALY5bTG:ALP<0T`L00`071`0`1`0300L702X7000;1`0300L700X7
00<01`L00PL047QbN79hLWQbN79hLWQbN783094700<01`L0<0L00`071`0Y1`002`L00`071`0;1`03
00L7008701:ALY5bTG:ALY5bTG:ALY5bTG8408d700<01`L0<0L00`071`0Y1`002`L00`071`0<1`80
0`L05GQbN79hLWQbN79hLWQbN79hLWQbN00308X700<01`L0<@L00`071`0X1`002`L00`071`0>1`0K
00L71i5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00<0Q`L00`071`0b1`0300L702L7000;1`0300L700l7
01d01`L7N79hLWQbN79hLWQbN79hLWQbN79hLWQbN00308@700<01`L0<PL00`071`0W1`002`L00`07
1`0@1`0O00L71i5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@04080700<01`L0<`L00`071`0V1`00
2`L00`071`0A1`0R00L71gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP<0O@L00`071`0d1`03
00L702D7000:1`0300L701<702@01`L7TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8307X7
00<01`L0=0L00`071`0U1`002PL00`071`0D1`0V00L71gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN78307L700<01`L0=@L00`071`0T1`002PL00`071`0E1`0X00L71i5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP@0L`L00`071`0f1`0300L702<7000:1`0300L701H702/01`L7
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00<0L0L00`071`0f1`0300L702<7
000:1`0300L701L702d01`L7TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40
0`1/1`80>@L00`071`0R1`002PL00`071`0H1`0_00L71gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWP0101U1`<00PL00`071`0g1`0300L7024700091`0300L701X703801`L7
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<0G`L300H700<01`L0
=PL00`071`0Q1`002@L00`071`0K1`0d00L71gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLP<0F@L300T700<01`L0=`L00`071`0P1`002@L00`071`0L1`0f00L71i5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0`1D1`803@L00`07
1`0g1`0300L701l700091`0300L701d703P01`L7N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLP@0C@L3010700<01`L0=PL00`071`0O1`002@L00`071`0N1`0k
00L71i5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40
0`171`<050L00`071`0f1`0300L701h700091`0300L701l703d01`L7N79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00<0@@L301L700<01`L0=`L00`07
1`0M1`002@L00`071`0P1`0o00L71i5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:A00<0>`L301/700<01`L0=PL00`071`0M1`0020L00`071`0R1`11
00L71gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWP0100d1`<07`L00`071`0f1`0300L701`700081`0300L702<704@01`L7TG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<0;PL302<7
00<01`L0=PL00`071`0K1`0020L00`071`0T1`1600L71gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP<0:0L302H700<01`L0=PL00`07
1`0K1`0020L00`071`0U1`1800L71i5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b100Q1`<0:PL00`071`0f1`0300L701X700081`03
00L702H704/01`L7N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWP00`0L1`80;PL00`071`0f1`0300L701T700081`0300L702L7
04d01`L7TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@0301H70`0a1`0300L703D700<01`L06@L000P700<01`L0:0L0C`07
1`MhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWP00`0@1`<0=0L00`071`0f1`0300L701P700071`0300L702X705401`L7
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY4010091`<0>0L00`071`0f1`0300L701L700071`0300L702/705@01`L7
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN78300<70`0l1`0300L703H700<01`L05PL000L700<01`L0;0L20087
05:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0`101`0300L703D700<01`L05PL000L700<01`L0;PL0D@07
1gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP030003LWQb00<0?@L00`071`0f1`0300L701D700071`0300L702l7
04d01`NALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALP030009LY5bTG:ALY5b00@0>PL00`071`0f1`0300L701@700071`03
00L7030704X01`MhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN080011bN79hLWQbN79hLWQbN79h0`0h1`0300L703D700<01`L0
50L000L700<01`L0<@L0AP071i5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY43000ETG:ALY5bTG:ALY5bTG:ALY5bTG:A00<0=PL00`07
1`0e1`0300L701<700061`0300L703<704801`MhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP3000KN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79h00@0<`L00`071`0e1`0300L7018700061`0300L703@703h01`NALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@<002:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5b0`0`1`0300L703D700<01`L04PL000H700<01`L0=@L0>P071gQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP3000XN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP<0;PL00`071`0e1`0300L7014700061`03
00L703H703H01`NALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY43000^TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<0;0L00`07
1`0e1`0300L7010700061`0300L703L703801`MhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN0<003AhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQb100Y1`0300L703@700<01`L040L000H700<01`L0>0L0;P071i5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY43000kTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400`0V1`0300L703D700<01`L03`L000H7
00<01`L0>@L0:`071gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800P00@GQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79h00<090L00`071`0e1`0300L700h700051`0300L703/702L01`NALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG800`00AW:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY43028700<01`L0=0L00`071`0>1`001@L00`07
1`0l1`0S00L7N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800`00C79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWP401l700<01`L0=0L00`071`0=1`001@L00`071`0m1`0O00L7TG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALP03001CLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG800`0L1`0300L703D700<01`L030L000D7
00<01`L0?PL06`071gQbN79hLWQbN79hLWQbN79hLWQbN79hLP03001ILWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN7800`0J1`0300L703@700<01`L030L000D700<01`L0?`L05`071i5bTG:ALY5bTG:A
LY5bTG:ALY5b00<005mbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0401L700<01`L0
=0L00`071`0;1`001@L00`071`101`0C00L7N79hLWQbN79hLWQbN79hLP03001VLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0`0E1`0300L703@700<01`L02PL000D700<01`L0
@@L03`071i5bTG:ALY5bTG:ALP03001/LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:A0`0B1`0300L703@700<01`L02PL000@700<01`L0@`L02`071gQbN79hLWQb00<0
079bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP30107
00<01`L0<`L200/700041`0300L704@700P01`NALY5bT@8007QbTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4400d700<01`L0;`L300031`0700X7
00041`0300L704D700@01`Mh0`00OWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP<02`L00`071`0Z1`@010L00`071`091`0010L00`07
1`161`<008BALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG8300P700<01`L09`L300P700<01`L02@L000@700<01`L0@`L3002:
1`071gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQb0`061`0300L702<70`0;1`0300L700T700041`0300L704070`051`2;
00L7TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALP0400<700<01`L07`L300l700<01`L020L000@700<01`L0?@L300T7
08h01`MhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79h0`000`L01`0K1`@04PL00`071`081`000`L00`071`0k1`<0
3@L2002>1i5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@<060L301H700<01`L020L000<700<01`L0>0L30187
09001gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN78501470`0I1`0300L700P700031`0300L703H70P0F1`2D
00NALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALP<02`L301`700<01`L020L000<700<01`L0<`L301T7
09H01gQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN780LWQbN78200D7100O1`0300L700P700031`0300L70307
0`0M1`2B00NALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b078300@70`0S1`0300L700P700031`0300L702d7
0`0Q1`2=00MhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00@000AbN0L70`0V1`0300L700P700021`0300L702/7
0`0U1`2900L7LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400`001I5bT@2A00<0:PL00`071`071`000PL00`071`0X1`<0
:@L0Q@071g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWP00`0027QbN79hLWP0;@L00`071`071`000PL00`071`0U1`<0;@L0P@07
1g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bT@030009TG:ALY5bTG:A008700<01`L0:PL00`071`071`000PL00`071`0R1`<0<@L0O007
1g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N784000;N79hLWQbN79hLWP00`L00`071`0Z1`0300L700L700021`0300L702070P0e1`1h00L7LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0`003W:A
LY5bTG:ALY5bTG:A1@L00`071`0Y1`0300L700L700021`0300L701d70`0h1`1d00L7LWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN783000@LWQbN79hLWQbN79h
LWQbN0L700<01`L0:0L00`071`071`000PL00`071`0J1`<0?0L0L0071g:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG83000ALY5bTG:ALY5bTG:ALY5bTG802PL00`07
1`0W1`0300L700L700000`L01`0I1`<0@0L0J`071g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79h00@001=bN79hLWQbN79hLWQbN79hLWQb00/700<01`L09`L00`071`071`00
00<700L05PL304@706L01`MbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00<0
01JALY5bTG:ALY5bTG:ALY5bTG:ALY5b3@L00`071`0V1`0300L700L700000`L01`0C1`<0B0L0H`07
1g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN003000HN79hLWQbN79hLWQbN79hLWQb
N79hLWQb3`L00`071`0V1`0300L700H700000`L01`0@1`<0C0L0G`071g:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:A00<001ZALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALQ4700<01`L09@L00`07
1`061`0000<700L03@L3050705X01`MbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN784000LN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLQ8700<01`L09@L00`071`061`0000<700L02PL305@705H01`Mb
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<001mbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b01@7
00<01`L090L00`071`061`0000<700L020L205P705801`MbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb0`008G9h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0F1`0300L702<700<01`L01PL0000300L700D7
0`1K1`1>00L7LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0`008g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5b01P700<01`L08PL00`071`061`0000<01`L00PL305l704T01`MbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00@002AbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWPK1`0300L7024700<01`L01PL0000300L00080
H`L0A@071g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bT@03000WTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A01`7
00<01`L08@L00`071`061`000P1W1`1100L7LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00`00:GQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79h01h700<01`L08@L00`071`051`0000<700L0I`L0?@071g:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400`00:i5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4080L00`071`0P1`0300L700D700021`80
I`L0>0071g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
1000;GQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN00R1`0300L701l7
00<01`L01@L000@700<01`L0I@L0=0071g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG83000`LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:A8`L00`071`0O1`0300L700D700051`0300L706D70P00;`MbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0080039bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN2D700<01`L07PL00`071`051`001PL00`071`1V1`0a00MbTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP02000_TG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY409`L00`071`0M1`0300L700D700071`80
I`L0<P07LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0P00;79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h:@L00`071`0L1`0300L700D7
00091`0300L706D703<01g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG800P00:95bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8[1`0300L701`7
00<01`L01@L000X700<01`L0I@L0=007LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWP2000ULWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0]1`03
00L701/700<01`L01@L000/700<01`L0I@L0=@07LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5b00<0025bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80
;`L00`071`0K1`0300L700@7000<1`80IPL0=`07LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN7800P007WQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLS47
00<01`L06PL00`071`041`003PL00`071`1T1`0h00MbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY42000KLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0387
00<01`L06PL00`071`041`003`L00`071`1T1`0i00MbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb008001QhLWQbN79hLWQbN79hLWQbN79hLWQbN78d1`03
00L701T700<01`L010L0010700<01`L0I0L0>P07LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY42000ELY5bTG:ALY5bTG:ALY5bTG:ALY5b03H700<01`L0
60L00`071`041`004@L206D703/01g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP03000ALWQbN79hLWQbN79hLWQbN780>0L00`071`0G1`0300L700@7
000C1`0300L706<703d01g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5b008000fALY5bTG:ALY5bTG:A03/700<01`L05PL00`071`041`0050L00`07
1`1S1`0n00MbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWP2000:LWQbN79hLWQbN3`700<01`L05PL00`071`041`005@L00`071`1S1`8003ebTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0080
00NALY5bTG:A03h700<01`L05PL00`071`031`005PL206<704401`MbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0020004LWQbN40700<01`L0
5@L00`071`031`0060L00`071`1P1`1300L71g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP03048700<01`L050L00`071`031`006@L00`07
1`1O1`0300L70087045bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP02040700<01`L050L00`071`031`006PL00`071`1N1`0300L700<7
049bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY4203l700<01`L04`L00`071`031`006`L205h700<01`L010L0@g9hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800P0n1`03
00L7018700<01`L00`L001d700<01`L0F`L00`071`051`14LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4303`700<01`L04@L00`07
1`031`007PL00`071`1J1`0300L700H704IbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0P0j1`0300L7014700<01`L00`L001l7
00<01`L0F@L00`071`071`17LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG800P0i1`0300L7010700<01`L00`L002070P1I1`03
00L700P704QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWP203P700<01`L040L00`071`021`008PL00`071`1F1`0300L700T7
04UbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5b0080=`L00`071`0?1`0300L70087000S1`0300L705D700<01`L02PL0BW9h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79h0`0d1`0300L700l700<01`L00PL002@700<01`L0E0L00`071`0;1`1<LY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bT@80:PL500@700<01`L03PL00`071`021`009@L205@700<01`L030L0CG9hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQb00807PL:0004N79h00H700<01`L03@L00`071`021`009`L00`071`1A1`0300L700d7
04ibTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY4201872P003G:ALY5bTG:ALY5bT@0020L00`071`0<1`0300L70087
000X1`0300L7050700<01`L03PL0Cg9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800P061`X001IhLWQbN79hLWQb
N79hLWQbN79hLWP02@L00`071`0<1`0300L70087000Y1`0300L704l700<01`L03`L0D7:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:A1P007g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@002`L00`071`0;1`03
00L70087000Z1`80C`L00`071`0@1`1aLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN7800P0=1`0300L700/700<01`L00@L002`700<01`L0C0L00`071`0A1`1`
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b010700<01`L0
2PL00`071`011`00;@L00`071`1;1`0300L7018706ibN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQb018700<01`L02@L00`071`011`00;PL00`071`1:1`0300L701<7
06abTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0C1`0300L700T7
00<01`L00@L002l70P191`0300L701D706YbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN7805@L00`071`081`0300L70047000a1`0300L704H700<01`L05PL08W:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY420014LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0G1`0300L700L700<01`L00@L00387
00<01`L0A@L00`071`0G1`0RLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0<0045hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
000I1`0300L700H700<01`L00@L003<700<01`L0A0L00`071`0H1`0TLY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5b07:A0P00?W:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG806PL00`071`061`0300L70047000d1`80A0L00`071`0I1`0U
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLP02000kN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0070L00`071`051`0300L70047
000f1`0300L7044700<01`L06PL09W:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:A
0P00>7:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80
7PL00`071`051`400@L11`00=`L00`071`101`0300L701/702MbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN01hLWQbN7800`00<W9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79h0P0P1`0300L700@70@011`47000h1`0300L703l700<01`L070L0:G:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG80LY5bTG:ALY5b0080032ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@0R1`0300L700@70@011`47000i1`80?`L00`071`0M1`0Z
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79h0P00;G9hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h000T1`0300L700<70@011`47000k1`0300L703`7
00<01`L07PL0:g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG800P00:Y5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A02H700<01`L00PL100470@L003`7
00<01`L0>`L00`071`0O1`0/LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79h
LWP2000WLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP002P700D01`L700021`00
?@L00`071`0j1`0300L7020702ebTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:A
LY5bTG800P00995bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A02T700D01`L700021`00
?PL00`071`0i1`0300L702470P00;79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79h
LWQbN79h0`0087QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP0:`L010071`021`00?`L203T7
00<01`L08`L3000/LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY42000M
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@00;@L010071`011`00@@L00`071`0f1`0300L702H7
0P00;7QbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQb0P006WQbN79hLWQb
N79hLWQbN79hLWQbN79hLWP0;`L00`0700011`00@PL00`071`0e1`0300L702P70`00:i5bTG:ALY5b
TG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY400P005g:ALY5bTG:ALY5bTG:ALY5bTG:A
LY40030700<01`000@L004<700<01`L0=0L00`071`0[1`<002YhLWQbN79hLWQbN79hLWQbN780LWQb
N79hLWQbN79hLWQbN79hLWQbN782000DN79hLWQbN79hLWQbN79hLWQbN00b1`800@L004@70P0d1`03
00L702h70`004I5bTG:ALY5bTG:ALY5bTG80008701IbTG:ALY5bTG:ALY5bTG:ALY5bTG:A0`003Y5b
TG:ALY5bTG:ALY5b0P0c1`800@L004H700<01`L0<@L00`071`0a1`8000mbN79hLWQbN79hLWQbN000
2@L04W9hLWQbN79hLWQbN79hLWQbN08000abN79hLWQbN79hLP0a1`@00`L004L700<01`L0<0L00`07
1`0c1`<000ebTG:ALY5bTG:ALY4000l700ebTG:ALY5bTG:ALY5b008000VALY5bTG:ALP00;PL400L7
00181`0300L702l700<01`L0=PL3000:LWQbN79hLWQb01H700QbN79hLWQbN08000IbN79hLP0[1`@0
2`L004T70P0_1`0300L703T70`0027:ALY5bTG8070L00g:ALP020003TG8002P7100?1`00B`L00`07
1`0/1`0300L703`70`001G9hLWP002470P0U1`@04`L004`700<01`L0:`L00`071`0o1`8000BALY40
@`L401L7001=1`0300L702X700<01`L0@@L403l7100K1`00CPL202X700<01`L0A0L203X7100O1`00
D0L00`071`0W1`0300L707`7100S1`00D@L00`071`0V1`0300L707P7100W1`00DPL00`071`0U1`03
00L707@7100[1`00D`L202D700<01`L0L0L402l7001E1`0300L7028700<01`L0K0L403<7001F1`03
00L7024700<01`L0J@L303L7001G1`0300L7020700<01`L0I@L403X7001H1`8080L00`071`1Q1`@0
?PL005X700<01`L07@L00`071`1M1`@0@PL005/700<01`L070L00`071`1I1`@0APL005`700<01`L0
6`L00`071`1E1`@0BPL005d70P0K1`0300L70547101>1`00G`L00`071`0H1`0300L704d7101B1`00
H0L00`071`0G1`0300L704T7101F1`00H@L00`071`0E1`0300L704H7101J1`00HPL201D700<01`L0
@PL405h7001T1`0300L7018700<01`L0?PL40687001U1`0300L7014700<01`L0>PL406H7001V1`03
00L7010700<01`L0=PL406X7001W1`8040L00`071`0c1`<0KPL006T700<01`L03@L00`071`0_1`@0
L@L006X700<01`L030L00`071`0[1`@0M@L006/700<01`L02`L00`071`0W1`@0N@L006`70P0;1`03
00L702<7101m1`00KPL00`071`081`0300L701l710211`00K`L00`071`071`0300L701/710251`00
L0L00`071`061`0300L701L710291`00L@L200H700<01`L04`L408d7001c1`0300L700<700<01`L0
3`L40947001d1`0300L7008700<01`L02`L409D7001e1`0500L71`002@L409T7001f1`8000<700L0
10L409d7001h1`8000<700000P2Q1`00N@L20:D70000\
\>"],
  ImageRangeCache->{{{0, 287}, {256.688, 0}} -> {-0.000295015, 0.0287516, \
0.0033007, 0.0033007}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[10]= "]
}, Open  ]],

Cell["This gives the triangulation.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(triang3D = SimplePolygonTriangulation3D[data3D]\)], "Input",
  CellLabel->"In[11]:= "],

Cell[BoxData[
    \({{6, 3, 4}, {5, 6, 4}, {3, 1, 2}, {3, 6, 7}, {1, 3, 7}, {11, 1, 
        7}, {11, 7, 8}, {10, 11, 8}, {9, 10, 8}}\)], "Output",
  CellLabel->"Out[11]= "]
}, Open  ]],

Cell["This replaces the indices by the corresponding points.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(triangPoints3D = Map[Part[data3D, #] &, triang3D]\)], "Input",
  CellLabel->"In[12]:= "],

Cell[BoxData[
    \({{{10.3`, 12.3`, 6.78`}, {6.9`, 12.8`, 5.910000000000001`}, {9.5`, 
          14.9`, 7.319999999999999`}}, {{13.2`, 11.9`, 7.53`}, {10.3`, 12.3`, 
          6.78`}, {9.5`, 14.9`, 7.319999999999999`}}, {{6.9`, 12.8`, 
          5.910000000000001`}, {4.4`, 14, 5.52`}, {6.7`, 15.25`, 
          6.585`}}, {{6.9`, 12.8`, 5.910000000000001`}, {10.3`, 12.3`, 
          6.78`}, {6.8`, 9.5`, 4.89`}}, {{4.4`, 14, 5.52`}, {6.9`, 12.8`, 
          5.910000000000001`}, {6.8`, 9.5`, 4.89`}}, {{2.45`, 4.7`, 
          2.145`}, {4.4`, 14, 5.52`}, {6.8`, 9.5`, 4.89`}}, {{2.45`, 4.7`, 
          2.145`}, {6.8`, 9.5`, 4.89`}, {13.3`, 7.7`, 6.3`}}, {{1.3`, 2.4`, 
          1.11`}, {2.45`, 4.7`, 2.145`}, {13.3`, 7.7`, 6.3`}}, {{0.6`, 1.1`, 
          0.51`}, {1.3`, 2.4`, 1.11`}, {13.3`, 7.7`, 6.3`}}}\)], "Output",
  CellLabel->"Out[12]= "]
}, Open  ]],

Cell["The triangles cover the whole polygon.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Graphics3D[Map[Polygon[#] &, triangPoints3D]]]\)], "Input",
  CellLabel->"In[13]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .90377 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.05779 -0.0267649 1.05779 [
[ 0 0 0 0 ]
[ 1 .90377 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04618 .241 m
0 .55492 L
s
0 .55492 m
.42859 .90377 L
s
.42859 .90377 m
.43581 .61967 L
s
.43581 .61967 m
.04618 .241 L
s
.65429 0 m
.96301 .45879 L
s
.96301 .45879 m
1 .75698 L
s
1 .75698 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.04618 .241 m
0 .55492 L
s
0 .55492 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.65429 0 m
.04618 .241 L
s
.43581 .61967 m
.96301 .45879 L
s
.96301 .45879 m
1 .75698 L
s
1 .75698 m
.42859 .90377 L
s
.42859 .90377 m
.43581 .61967 L
s
0 0 m
1 0 L
1 .90377 L
0 .90377 L
closepath
clip
newpath
.5 Mabswid
.28743 .42405 m .57581 .73994 L .57745 .58929 L closepath p .547 .62 .877 r
F P
0 g
s
.57581 .73994 m .65226 .702 L .57745 .58929 L closepath p .547 .62 .877 r
F P
0 g
s
.65226 .702 m .57581 .73994 L .69367 .78112 L closepath p .547 .62 .877 r
F P
0 g
s
.65226 .702 m .7887 .68538 L .57745 .58929 L closepath p .547 .62 .877 r
F P
0 g
s
.7887 .68538 m .65226 .702 L .80495 .77242 L closepath p .547 .62 .877 r
F P
0 g
s
.91454 .67106 m .7887 .68538 L .80495 .77242 L closepath p .547 .62 .877 r
F P
0 g
s
.28743 .42405 m .57745 .58929 L .83321 .51308 L closepath p .547 .62 .877 r
F P
0 g
s
.18377 .34134 m .28743 .42405 L .83321 .51308 L closepath p .547 .62 .877 r
F P
0 g
s
.12229 .29401 m .18377 .34134 L .83321 .51308 L closepath p .547 .62 .877 r
F P
0 g
s
.25 Mabswid
.65429 0 m
.96301 .45879 L
s
.96301 .45879 m
1 .75698 L
s
1 .75698 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.04618 .241 m
0 .55492 L
s
0 .55492 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.65429 0 m
.04618 .241 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{288, 260.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000110P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53J`00?g=cLda<C2LW9b40<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7iYW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`c
olaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lco
I/coVLcoc<coool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI
0?nI<onII_nIVOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<okX70P1T1`00^0L200031`0006<7002e1`<0
0`L206<7002c1`801PL00`07001R1`00/0L300P700@01`L0H@L00:h70P0;1`0400L70647002[1`<0
3@L01@071`L00607002Y1`8040L00`071`021`0300L705d7002V1`<04PL00`071`021`0300L705d7
002T1`805@L00`071`031`0300L705`7002Q1`<05`L00`071`041`0300L705/7002N1`<06PL00`07
1`041`0300L705/7002L1`807PL00`071`041`0300L705X7002I1`<080L00`071`051`0300L705T7
002G1`808`L00`071`051`0300L705T7002D1`<09@L00`071`061`0300L705P7002B1`80:0L00`07
1`071`0300L705L7002?1`<0:PL00`071`071`0300L705L7002=1`80;@L00`071`081`0300L705H7
002:1`<0;`L00`071`091`0300L705D700281`80<PL00`071`091`0300L705D700251`<0=0L00`07
1`0:1`0300L705@700231`80=`L00`071`0;1`0300L705<700201`<0>@L00`071`0<1`0300L70587
001n1`80?0L00`071`0<1`0300L70587001k1`<0?PL00`071`0=1`0300L70547001i1`80@@L00`07
1`0>1`0300L70507001f1`<0@`L00`071`0>1`0300L70507001d1`80APL00`071`0?1`0300L704l7
001a1`<0B0L00`071`0@1`0300L704h7001_1`80B`L00`071`0@1`0300L704h7001/1`<0C@L00`07
1`0A1`0300L704d7001Z1`80D0L00`071`0B1`0300L704`7001W1`<0DPL00`071`0B1`0300L704`7
001T1`<0E@L00`071`0C1`0300L704/7001R1`80F0L00`071`0D1`0300L704X7001O1`<0F`L00`07
1`0C1`0300L704X7001M1`80GPL00`071`0D1`0300L704T7001J1`<0H0L00`071`0E1`0300L704P7
001H1`80H`L00`071`0E1`0300L704P7001E1`<0I@L00`071`0F1`0300L704L7001C1`80J0L00`07
1`0G1`0300L704H7001@1`<0JPL00`071`0G1`0300L704H7001>1`80K@L00`071`0H1`0300L704D7
001;1`<0K`L00`071`0I1`0300L704@700191`80LPL00`071`0I1`0300L704@700161`<0M0L00`07
1`0J1`0300L704<700141`80M`L00`071`0K1`0300L7048700111`<0N@L00`071`0K1`0300L70487
000o1`80O0L00`071`0L1`0300L70447000l1`<0OPL00`071`0M1`0300L70407000j1`80P@L00`07
1`0M1`0300L70407000g1`<0P`L00`071`0N1`0300L703l7000e1`80QPL00`071`0O1`0300L703h7
000b1`<0R0L00`071`0O1`0300L703h7000`1`80R`L00`071`0P1`0300L703d7000]1`<0S@L00`07
1`0Q1`0300L703`7000Z1`<0T0L00`071`0Q1`0300L703`7000X1`80T`L00`071`0R1`0300L703/7
000U1`<0UPL00`071`0R1`0300L703X7000S1`80V@L00`071`0R1`0300L703X7000P1`<0V`L00`07
1`0S1`0300L703T7000N1`80WPL00`071`0T1`0300L703P7000K1`<0X0L00`071`0T1`0300L703P7
000I1`80X`L00`071`0U1`0300L703L7000F1`<0Y@L00`071`0V1`0300L703H7000D1`80Z0L00`07
1`0V1`0300L703H7000A1`<0ZPL00`071`0W1`0300L703D7000?1`80[@L00`071`0X1`0300L703@7
000=1`80[`L00`071`0Y1`0300L703<7000=1`80[`L00`071`0Y1`0300L703<7000=1`0300L00:h7
00<01`L0:PL00`071`0b1`003@L010071`2]1`0300L702/700<01`L0<@L000`700<01`L00PL00`07
1`2Z1`0300L702/700<01`L0<@L000`700<01`L00`L00`071`2Y1`0300L702`700<01`L0<0L000`7
00<01`L010L00`071`2X1`0300L702d700<01`L0;`L000`700<01`L01@L00`071`2W1`0300L702d7
00<01`L0;`L000`700<01`L01PL00`071`2V1`0300L702h700<01`L0;PL000`700<01`L01`L00`07
1`2U1`0300L702l700<01`L0;@L000`700<01`L020L00`071`2T1`0300L702l700<01`L0;@L000/7
00<01`L02PL00`071`2S1`0300L7030700<01`L0;0L000/700<01`L02`L00`071`2R1`0300L70347
00<01`L0:`L000/700<01`L030L00`071`2Q1`0300L7034700<01`L0:`L000/700<01`L03@L00`07
1`2Q1`0300L7034700<01`L0:PL000/700<01`L03PL00`071`2P1`0300L7038700<01`L0:@L000/7
00<01`L03`L00`071`031`80VPL00`071`0b1`0300L702T7000;1`0300L7010700<01`L00`L409L7
00<01`L0<`L00`071`0X1`002PL00`071`0B1`8010L20003LP000080T`L00`071`0d1`0300L702L7
000:1`0300L701@700<01`L00`L01@1bN79h00<0T0L00`071`0d1`0300L702L7000:1`0300L701D7
00<01`L00`L01`1bTG:ALY400`2=1`0300L703D700<01`L09PL000X700<01`L05PL00`071`031`80
00MhLWQbN79h00@0R@L00`071`0f1`0300L702D7000:1`0300L701L700<01`L010L02`2ALY5bTG:A
LY5b00<0QPL00`071`0f1`0300L702D7000:1`0300L701P700<01`L010L03@1hLWQbN79hLWQbN780
0`231`0300L703L700<01`L090L000X700<01`L06@L00`071`041`8000ebTG:ALY5bTG:ALY5b00<0
P0L00`071`0h1`0300L702<700091`0300L701/700<01`L01@L0401bN79hLWQbN79hLWQbN78407/7
0P0j1`0300L702<700091`0300L701`700<01`L01@L04`1bTG:ALY5bTG:ALY5bTG:ALY400`1e1`<0
0PL00`071`0h1`0300L7028700091`0300L701d700<01`L01@L2000CN79hLWQbN79hLWQbN79hLWQb
N00306l70`061`0300L703P700<01`L08@L000T700<01`L07PL00`071`061`0F095bTG:ALY5bTG:A
LY5bTG:ALY5bT@@0J0L300T700<01`L0>0L00`071`0Q1`002@L00`071`0O1`0300L700H70P005g9h
LWQbN79hLWQbN79hLWQbN79hLWQb00<0HPL300d700<01`L0>0L00`071`0P1`002@L00`071`0P1`03
00L700H71@005Y5bTG:ALY5bTG:ALY5bTG:ALY5bTG8305`70`0A1`0300L703P700<01`L07`L000T7
00<01`L08@L00`071`061`8000=bN0000`005G9hLWQbN79hLWQbN79hLWQbN79hLP0305H70`0E1`03
00L703L700<01`L07`L000P700<01`L08`L00`071`071`0607:ALY5b1000595bTG:ALY5bTG:ALY5b
TG:ALY5b101?1`<060L00`071`0h1`0300L701h700081`0300L702@700<01`L01`L02@1bN79hLWQb
N004000DLWQbN79hLWQbN79hLWQbN79hLWP304X70P0L1`0300L703P700<01`L07@L000P700<01`L0
9@L00`071`071`0<07:ALY5bTG:ALY5b0`0057:ALY5bTG:ALY5bTG:ALY5bTG:A0`141`<07`L00`07
1`0g1`0300L701d700081`0300L702H700<01`L01`L2000<N79hLWQbN79hLWQb10004gQbN79hLWQb
N79hLWQbN79hLWP0100m1`<08`L00`071`0g1`0300L701`700081`0300L702L700<01`L020L0402A
LY5bTG:ALY5bTG:ALY44000CLY5bTG:ALY5bTG:ALY5bTG:ALP0303L70`0V1`0300L703P700<01`L0
6`L000P700<01`L0:0L00`071`081`0C07QbN79hLWQbN79hLWQbN79hLP04000BN79hLWQbN79hLWQb
N79hLWQb0`0a1`<0:PL00`071`0g1`0300L701/700081`0300L702T700<01`L020L05P2ALY5bTG:A
LY5bTG:ALY5bTG:ALY44000ALY5bTG:ALY5bTG:ALY5bTG80100Z1`<0;PL00`071`0g1`0300L701X7
00071`0300L702/700<01`L020L2000GLWQbN79hLWQbN79hLWQbN79hLWQbN78010004GQbN79hLWQb
N79hLWQbN79h00<090L3038700<01`L0=`L00`071`0I1`001`L00`071`0/1`0300L700T701/0LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400`004I5bTG:ALY5bTG:ALY5bTG:A00<07PL303H700<01`L0
=PL00`071`0I1`001`L00`071`0]1`0300L700T701d0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N004000@LWQbN79hLWQbN79hLWQbN0<060L303T700<01`L0=`L00`071`0H1`001`L00`071`0^1`03
00L700T70200LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP@000nALY5bTG:ALY5bTG:ALY40
100A1`<0?@L00`071`0g1`0300L701L700071`0300L702l700<01`L02@L2000QN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79h00@000mbN79hLWQbN79hLWQbN7800`0;1`<0@@L00`071`0g1`03
00L701H700071`0300L7030700<01`L02PL09@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG8010003Y5bTG:ALY5bTG:ALY5b0`051`<0A@L00`071`0f1`0300L701H700071`0300L70347
00<01`L02PL0:01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP3000>N79hLWQb
N79hLWQbN78504P700<01`L0=`L00`071`0E1`001PL00`071`0c1`0300L700X702X0TG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY440009LY5bTG:ALY5b00<000=bT@000P171`03
00L703L700<01`L050L000H700<01`L0=0L00`071`0:1`8002]bN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQb00@000=hLP000P00279hLWQbN79h0`151`0300L703H700<01`L0
50L000H700<01`L0=@L00`071`0;1`0^07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALPD000abTG:ALY5bTG:ALY4304<700<01`L0=PL00`071`0C1`001PL00`071`0f1`03
00L700/702/0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h008000EbN79h
LP04000;N79hLWQbN79hLWP010101`0300L703H700<01`L04PL000H700<01`L0=`L00`071`0;1`0W
07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00<000^ALY5bTG:ALY5bT@04000;
LY5bTG:ALY5bTG800`0m1`0300L703H700<01`L04PL000H700<01`L0>0L00`071`0;1`80025hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00`004WQbN79hLWQbN79hLWQbN79hLP<000]bN79h
LWQbN79hLP0303/700<01`L0=PL00`071`0A1`001@L00`071`0j1`0300L700`701h0TG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY43000HTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b10002Y5bTG:ALY5b
TG8403P700<01`L0=PL00`071`0@1`001@L00`071`0k1`0300L700`710005W9hLWQbN79hLWQbN79h
LWQbN79hLWP3000ON79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN004000:LWQbN79hLWQbN0<0
=PL00`071`0e1`0300L7010700051`0300L703`700<01`L030L20003LP0000@000fALY5bTG:ALY5b
TG:A00<002JALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP@000VALY5bTG:ALY40
0`0c1`0300L703H700<01`L03`L000D700<01`L0?@L200d70`001GQbN79h00H000AbN79h0`00;GQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0040008LWQbN79hLWP30347
00<01`L0=PL00`071`0>1`001@L00`071`0o1`0300L700/700d0T@00LY5bTG:ALY5b00H003:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<000QbTG:ALY5bT@@0
;PL00`071`0e1`0300L700h700051`0300L7040700<01`L02`L02P1hLP1bN79hLWP30005N79hLWP0
1`00;WQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7840008N79hLWQb
N78302`700<01`L0=@L00`071`0=1`001@L00`071`111`0300L700/700<0TG800P004i40002ALY5b
TG:ALY5bTG:ALY401P00;7:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
10001g:ALY5bTG800`0Y1`0300L703H700<01`L030L000@700<01`L0@`L00`071`0:1`03079h00@0
01MbN79hLWQbN79hLWQbN79hLWQbN79hLP06000ZN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQb10001WQbN79hLP@09PL00`071`0e1`0300L700`700041`0300L704@700<01`L0
2@L30004TG:ALP8001^ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY401`009i5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@040006LY5bTG:A0`0T1`0300L703D700<01`L02`L000@7
00<01`L0A@L00`071`051`<00PL01`1bN79hLWP00P00879hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79h1P009G9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN78010001GQbN79h00<0
8PL00`071`0e1`0300L700X700041`0300L704H700@01`L70`061`0^07:ALY5bTG80LY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALPH002>ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bT@030005TG:ALY400`0P1`0300L703@700<01`L02PL000@700<01`L0A`L300X700P0LWQb
N79hLP8002UhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN006000PLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP40004LWQbN0@070L00`071`0d1`802`L000@700<01`L0
A0L300031`0700/700T0LY5bTG:ALY400P00;G:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALP07000MLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG801000195bTG8301X7
00<01`L0<0L300031`0700X700041`0300L704470`051`0300L700X700X0LWQbN79hLWQb0P00<WQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb1P006gQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN0040003LWQb00<060L00`071`0[1`@010L00`071`091`000`L00`07
1`101`802@L00`071`0:1`1307:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@06000ILY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP040003
TG8000<05@L00`071`0W1`<020L00`071`091`000`L00`071`0m1`<030L00`071`0:1`0;079hLWQb
N79hLWP00P00>g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQb00L001IbN79hLWQbN79hLWQbN79hLWQbN79h0`000gQbN003018700<01`L090L300/7
00<01`L02@L000<700<01`L0>PL3010700<01`L02PL0301bTG:ALY5bTG:ALP80042ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1P004i5b
TG:ALY5bTG:ALY5bTG:ALY4010000g:A0002010700<01`L07`L400l700<01`L020L000<700<01`L0
=`L301@700<01`L02PL03@1bN79hLWQbN79hLWP00P00A79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h1P004G9hLWQbN79hLWQbN79h
LWQb00@000=h00000P0=1`0300L701/70`0C1`0300L700P700031`0300L703@70`0H1`0300L700X7
05P0LY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1P003i5bTG:ALY5bTG:ALY5bT@040004LP0000/7
00<01`L05`L301H700<01`L020L000<700<01`L0<@L301`700<01`L02@L03`1hLWQbN79hLWQbN79h
LP02001=N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWP01`0037QbN79hLWQbN79hLPL02@L00`071`0C1`<06@L00`07
1`081`000`L00`071`0^1`<080L00`071`091`0@095bTG:ALY5bTG:ALY5bT@80059bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:A1P002W:ALY5bTG:ALY4600H700<01`L03`L401`700<01`L020L0008700<01`L0
;0L302@700<01`L02@L04@1hLWQbN79hLWQbN79hLWQb008005IhLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLPH000QhLWQbN79hLPH00`L00`071`0;1`<080L00`071`081`000PL00`071`0Y1`<0:0L00`07
1`091`1^095bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY470004
TG:ALPH000<700L020L302<700<01`L020L0008700<01`L09PL302`700<01`L02@L04P1hLWQbN79h
LWQbN79hLWQbN080061bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP60003LWP000@0
10L402H700<01`L020L0008700<01`L08`L3030700<01`L02@L04`2ALY5bTG:ALY5bTG:ALY5bTG80
0P00I95bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8;02/700<01`L01`L00087
00<01`L080L303@700<01`L02@L0501hLWQbN79hLWQbN79hLWQbN79h0P00J79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h200X1`0300L700L700021`0300L701d70`0h1`03
00L700T701D0TG:ALY5bTG:ALY5bTG:ALY5bTG800P00K95bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5b07:ALP@09PL00`071`071`000PL00`071`0J1`<0?0L00`071`091`1o
07QbN79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLP0502P700<01`L01`L000031`0701T70`101`0300L700T701H0TG:ALY5bTG:ALY5bTG:A
LY5bTG:A0P00I7:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4302`700<01`L0
1`L000031`0701H70`141`0300L700T701L0N79hLWQbN79hLWQbN79hLWQbN79hLP02001ON79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00`031`0300L702T700<01`L01`L000031`0701@7
0P181`0300L700P701T0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A008005UbTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALP0400L700<01`L0:0L00`071`071`0000<700L04@L304/700<01`L020L0L01b
N79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN78300`700<01`L0
9`L00`071`071`0000<700L03PL304l700<01`L020L06P1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
0P00D95bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0`0@1`0300L702H700<01`L01`L000031`0700/70`1C1`03
00L700P701/0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00P00BW9hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h100C1`03
00L702L700<01`L01PL000031`0700P70`1G1`0300L700P701`0LY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5b0P00AI5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@0301P700<01`L09PL00`071`061`0000<01`L01@L305/700<01`L0
20L0G`1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00<070L00`071`0U1`0300L700H7
00000`071`021`<0G`L00`071`081`0M07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400P00>g:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00@0
80L00`071`0T1`0300L700H700000`07000206<700<01`L020L07P1bN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLP8003IhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN78302@700<01`L090L00`071`061`000P1W1`0300L700P701l0LY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:A0080031bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY4402P700<01`L08`L00`071`061`0000<700L0I`L200T704d0LWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N00302d700<01`L08PL00`071`061`000PL206P700<01`L01`L0801bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5b0P009i5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@030347
00<01`L08@L00`071`061`0010L00`071`1V1`0300L700H70280N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79h0P008G9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0403D700<01`L0
8@L00`071`051`001@L00`071`1V1`0300L700H702<0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALP02000LTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<0>@L00`071`0Q1`0300L700D7
00061`0300L706H700<01`L01PL0901hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN080
01MbN79hLWQbN79hLWQbN79hLWQbN79hLP0303d700<01`L080L00`071`051`001`L00`071`1V1`03
00L700H703P0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:A
LY5bT@@0@@L00`071`0O1`0300L700D700081`80I`L00`071`061`0U07QbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP02000=N79hLWQbN79hLWQbN00304H700<01`L07PL00`071`051`00
2PL00`071`1U1`0300L700H702H0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@80
00QbTG:ALY5bT@<0B@L00`071`0N1`0300L700D7000;1`0300L706D700<01`L01PL09`1hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP020003N78000<0C@L00`071`0M1`0300L700D7
000<1`0300L706D700<01`L01PL0:02ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY42058700<01`L070L00`071`051`003@L206H700<01`L01PL09`1hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP04054700<01`L06`L00`071`051`003`L00`071`1T1`0300L700H7
02H0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@8000AbT@00C`L00`071`0L1`03
00L700@7000@1`0300L706@700<01`L01PL0:`1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN780LP1bN7800P1>1`0300L701/700<01`L010L0014700<01`L0I0L00`071`061`0/095bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095b07:ALY4204d700<01`L06PL00`071`041`00
4PL206D700<01`L01@L0;P1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN01hLWQb
N78204`700<01`L06@L00`071`041`0050L00`071`1S1`0300L700D702l0LY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@2ALY40TG:ALY5bT@0304X700<01`L060L00`071`041`005@L00`07
1`1S1`0300L700@70P00<79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79h07QbN79h
LWQbN080B0L00`071`0H1`0300L700@7000F1`0300L706<700<01`L00`021`0b07:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG80LY5bTG:ALY5bTG8204L700<01`L05`L00`071`041`00
5`L00`071`1S1`801PL0<`1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQb079hLWQb
N79hLWQbN00204H700<01`L05PL00`071`041`0060L206<700<01`L01PL0=01bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY40TG:ALY5b07:ALY5bTG:ALY5bTG8204D700<01`L05PL00`071`031`00
6PL00`071`1P1`0300L700L703D0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780LWQbN79h07Qb
N79hLWQbN79hLWQbN003048700<01`L05PL00`071`031`006`L00`071`1O1`0300L700P703L0LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:A0080@@L00`07
1`0E1`0300L700<7000L1`0300L705h700<01`L02@L0>01bN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N780LWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQb0P101`0300L701@700<01`L00`L001d70P1N1`03
00L700X703T0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG80LY5bTG:ALY5bTG:ALY5b
TG:ALY400P0o1`0300L701<700<01`L00`L001l700<01`L0F`L00`071`0;1`0j079hLWQbN79hLWQb
N79hLWQbN79hLWQbN780LWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLP80?PL00`071`0B1`03
00L700<7000P1`0300L705X700<01`L02`L0?02ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:A
LY5bTG80LY5bTG:ALY5bTG:ALY5bTG:ALY5bT@80?0L00`071`0B1`0300L700<7000Q1`0300L705T7
00<01`L030L0?@1hLWQbN79hLWQbN79hLWQbN79hLWQbN780LWQbN79hLWQbN01hLWQbN79hLWQbN79h
LWQbN79hLWQbN7800`0j1`0300L7014700<01`L00`L002870P1I1`0300L700d703l0TG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG800P0i1`03
00L7010700<01`L00`L002@700<01`L0EPL00`071`0>1`1007QbN79hLWQbN79hLWQbN79hLWQbN780
LWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN080>0L00`071`0@1`0300L70087
000U1`0300L705D700<01`L03`L0@@2ALY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5b07:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0080=PL00`071`0@1`0300L70087000V1`0300L705@7
00<01`L040L0@P1hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQb079hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN080=@L00`071`0?1`0300L70087000W1`0300L705<700<01`L04@L0@`2A
LY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG800`0c1`0300L700h700<01`L00PL002P70P1C1`0300L7018704D0N79hLWQbN79hLWQbN79h
LWQb079hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800P0b1`03
00L700d700<01`L00PL002X700<01`L0D0L00`071`0C1`16095bTG:ALY5bTG:ALY5bTG:A095bTG:A
LY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@809`L500@700<01`L0
3@L00`071`021`00:`L00`071`1?1`0300L701@704L0N79hLWQbN79hLWQbN79hLP1bN79hLWQbN79h
LWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0201`72@00179hLP061`03
00L700`700<01`L00PL002`700<01`L0CPL00`071`0E1`18095bTG:ALY5bTG:ALY5bT@2ALY5bTG:A
LY5bTG:ALY5b07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A0P0A1`T000abTG:A
LY5bTG:ALP081`0300L700/700<01`L00PL002d70P1>1`0300L701D704X0LWQbN79hLWQbN79hLWQb
079hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP80
1PL9000DLWQbN79hLWQbN79hLWQbN79hLP0:1`0300L700/700<01`L00@L002l700<01`L0B`L00`07
1`0F1`1907:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@08000LLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00`700<01`L0
2PL00`071`011`00<0L00`071`1:1`0300L701L70400LWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQb
N79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb20008GQbN01hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN00200d700<01`L02PL00`071`011`00<@L00`071`181`0300L701T703L0LY5b
TG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:A00P002UbTG:A
LY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A000@1`0300L700T700<01`L00@L00387
0P181`0300L701X702h0LWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQb
2000<7QbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h018700<01`L0
20L00`071`011`00=0L00`071`151`0300L701/702D0LY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5b
TG:ALP1bTG:A00P003MbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY4001@700<01`L01`L00`071`011`00=@L00`071`141`0300L701`701l0LWQbN79hLWQb
079hLWQbN79hLWQbN79hLWQbN79h00D003ihLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N780LWQbN79hLWQbN79hLWQbN79hLWQbN79h01D700<01`L01`L00`071`011`00=PL00`071`131`03
00L701d701`0LY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5b0P000i5b0002000mLY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:A000G1`0300L700H7
00<01`L00@L003L700<01`L0@PL00`071`0N1`0I079hLWQbN780LWQbN79hLWQbN79hLWQbN0020005
LWQbN0000PL2000jN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQb
N79hLWQbN79h01T700<01`L01@L00`071`011`00>0L2048700<01`L07`L05P1bTG:ALY40TG:ALY5b
TG:ALY5bTG820008TG:ALY5bT@031`8003MbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2A
LY5bTG:ALY5bTG:ALY5bTG:ALY4001/700<01`L01@L100470@L003X700<01`L0?`L00`071`0P1`0C
079hLWQb079hLWQbN79hLWQbN002000:LWQbN79hLWQb00D70P00=7QbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN00M1`0300L700@70@011`47000k1`0300L703h7
00<01`L08@L0401bTG:A095bTG:ALY5bTG82000=TG:ALY5bTG:ALY5b00061`8002mbTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALP0201h700<01`L010L100470@L003`7
00<01`L0?@L00`071`0Q1`0>07QbN780LWQbN79hLWP2000?LWQbN79hLWQbN79hLWP000P70P00;GQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQb000Q1`0300L700<70@011`47
000m1`80?@L00`071`0R1`0;095bT@2ALY5bTG800P004Y5bTG:ALY5bTG:ALY5bTG:A00T70`00:I5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG8002<700<01`L00PL100470@L003l7
00<01`L0>PL00`071`0S1`0807Qb079hLWP2000DLWQbN79hLWQbN79hLWQbN79hLP0<1`8002IbN79h
LWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQb02D700D01`L700021`00@0L00`071`0i1`03
00L702@700D0T@2ALP02000GTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP003@L2000STG:ALY5bTG:ALY5b
TG:ALY5bTG80LY5bTG:ALY5bTG:ALP009PL01@071`L0008700111`0300L703P700<01`L09@L4000I
LWQbN79hLWQbN79hLWQbN79hLWQbN79h000?1`80021bN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79h
LWQb02P700@01`L00PL004870P0h1`0300L702H70P006g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
000@1`8001fALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5b000Z1`0400L7004700141`0300L703D7
00<01`L0:0L3000ILWQbN79hLWQbN79hLWQbN79hLWQbN79h000A1`8001YbN79hLWQbN79hLWQbN780
LWQbN79hLWQb02`700<01`000@L004D700<01`L0=0L00`071`0[1`<001IbTG:ALY5bTG:ALY5bTG:A
LY5bTG804`L3000FLY5bTG:ALY5bTG:A095bTG:ALY5b02d700<01`000@L004H700<01`L0<`L00`07
1`0^1`<001AbN79hLWQbN79hLWQbN79hLWQb01D70P004gQbN79hLWQbN780LWQbN79hLP00;`L20047
00171`0300L7038700<01`L0<@L3000ALY5bTG:ALY5bTG:ALY5bT@005`L2000>LY5bTG:ALY40TG:A
LY4203070P011`00B0L2038700<01`L0=0L3000?LWQbN79hLWQbN79hLWP001P70P0037QbN79hLP1b
N79h02h710031`00BPL00`071`0_1`0300L703L710002i5bTG:ALY5bTG8001X70P002G:ALY5b07:A
000[1`@01`L004/700<01`L0;PL00`071`0k1`<000UhLWQbN79hLP006`L20006N79h07P0:0L400/7
001<1`0300L702d700<01`L0?PL30006TG:ALY407@L20003LP0002D7100?1`00C@L202d700<01`L0
@@L30004N79h01h70P0R1`@04`L004l700<01`L0:PL00`071`141`@0?PL401L7001@1`0300L702T7
00<01`L0A`L203T7100K1`00D@L00`071`0X1`0300L707l70`0O1`00DPL202P700<01`L0N`L40287
001D1`0300L702D700<01`L0M`L402H7001E1`0300L702@700<01`L0L`L402X7001F1`0300L702<7
00<01`L0K`L402h7001G1`0300L7028700<01`L0J`L40387001H1`808PL00`071`1W1`@0=PL005X7
00<01`L07`L00`071`1S1`@0>PL005/700<01`L07PL00`071`1O1`@0?PL005`700<01`L07@L00`07
1`1L1`<0@PL005d70P0M1`0300L705P710151`00G`L00`071`0J1`0300L705@710191`00H0L00`07
1`0I1`0300L70507101=1`00H@L00`071`0H1`0300L704`7101A1`00HPL201L700<01`L0B@L405D7
001T1`0300L701@700<01`L0A@L405T7001U1`0300L701<700<01`L0@@L405d7001V1`0300L70187
00<01`L0?PL30647001W1`0300L7014700<01`L0>PL406@7001X1`804@L00`071`0f1`@0J0L006X7
00<01`L03PL00`071`0b1`@0K0L006/700<01`L03@L00`071`0^1`@0L0L006`700<01`L030L00`07
1`0Z1`@0M0L006d70P0<1`0300L702H7101h1`00K`L00`071`091`0300L70287101l1`00L0L00`07
1`081`0300L701h710201`00L@L00`071`071`0300L701/70`241`00LPL200L700<01`L05`L408L7
001d1`0300L700@700<01`L04`L408/7001e1`0300L700<700<01`L03`L408l7001f1`0300L70087
00<01`L02`L409<7001g1`0500L71`002@L409L7001h1`8000<700L010L409/7001j1`8000<70000
0P2O1`00N`L20:<70000\
\>"],
  ImageRangeCache->{{{0, 287}, {259.25, 0}} -> {-0.000245383, 0.0252984, \
0.00329567, 0.00329567}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[13]= "]
}, Open  ]],

Cell[TextData[{
  "This triangulates the ",
  StyleBox["Polygon", "MR"],
  " primitive within a ",
  StyleBox["Graphics3D", "MR"],
  " object. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      TriangulateSimplePolygons3D[Graphics3D[Polygon[data3D]]]]\)], "Input",
  CellLabel->"In[14]:= "],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .90377 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.05779 -0.0267649 1.05779 [
[ 0 0 0 0 ]
[ 1 .90377 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04618 .241 m
0 .55492 L
s
0 .55492 m
.42859 .90377 L
s
.42859 .90377 m
.43581 .61967 L
s
.43581 .61967 m
.04618 .241 L
s
.65429 0 m
.96301 .45879 L
s
.96301 .45879 m
1 .75698 L
s
1 .75698 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.04618 .241 m
0 .55492 L
s
0 .55492 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.65429 0 m
.04618 .241 L
s
.43581 .61967 m
.96301 .45879 L
s
.96301 .45879 m
1 .75698 L
s
1 .75698 m
.42859 .90377 L
s
.42859 .90377 m
.43581 .61967 L
s
0 0 m
1 0 L
1 .90377 L
0 .90377 L
closepath
clip
newpath
.5 Mabswid
.28743 .42405 m .57581 .73994 L p .57745 .58929 L .547 .62 .877 r
F P
0 g
s
.57581 .73994 m .65226 .702 L .57745 .58929 L .547 .62 .877 r
F
.57581 .73994 m .69367 .78112 L .65226 .702 L p F P
0 g
s
.7887 .68538 m .57745 .58929 L p .65226 .702 L .547 .62 .877 r
F P
0 g
s
.65226 .702 m .80495 .77242 L p .7887 .68538 L .547 .62 .877 r
F P
0 g
s
.80495 .77242 m .91454 .67106 L .7887 .68538 L p .547 .62 .877 r
F P
0 g
s
.57745 .58929 m .83321 .51308 L p .28743 .42405 L .547 .62 .877 r
F P
0 g
s
.18377 .34134 m .28743 .42405 L p .83321 .51308 L .547 .62 .877 r
F P
0 g
s
.83321 .51308 m .12229 .29401 L .18377 .34134 L p .547 .62 .877 r
F P
0 g
s
.25 Mabswid
.65429 0 m
.96301 .45879 L
s
.96301 .45879 m
1 .75698 L
s
1 .75698 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.04618 .241 m
0 .55492 L
s
0 .55492 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.65429 0 m
.04618 .241 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 260.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000110P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53J`00?g=cLda<C2LW9b40<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7iYW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`c
olaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lco
I/coVLcoc<coool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI
0?nI<onII_nIVOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<okX70P1T1`00^0L200031`0006<7002e1`<0
0`L206<7002c1`801PL00`07001R1`00/0L300P700@01`L0H@L00:h70P0;1`0400L70647002[1`<0
3@L01@071`L00607002Y1`8040L00`071`021`0300L705d7002V1`<04PL00`071`021`0300L705d7
002T1`805@L00`071`031`0300L705`7002Q1`<05`L00`071`041`0300L705/7002N1`<06PL00`07
1`041`0300L705/7002L1`807PL00`071`041`0300L705X7002I1`<080L00`071`051`0300L705T7
002G1`808`L00`071`051`0300L705T7002D1`<09@L00`071`061`0300L705P7002B1`80:0L00`07
1`071`0300L705L7002?1`<0:PL00`071`071`0300L705L7002=1`80;@L00`071`081`0300L705H7
002:1`<0;`L00`071`091`0300L705D700281`80<PL00`071`091`0300L705D700251`<0=0L00`07
1`0:1`0300L705@700231`80=`L00`071`0;1`0300L705<700201`<0>@L00`071`0<1`0300L70587
001n1`80?0L00`071`0<1`0300L70587001k1`<0?PL00`071`0=1`0300L70547001i1`80@@L00`07
1`0>1`0300L70507001f1`<0@`L00`071`0>1`0300L70507001d1`80APL00`071`0?1`0300L704l7
001a1`<0B0L00`071`0@1`0300L704h7001_1`80B`L00`071`0@1`0300L704h7001/1`<0C@L00`07
1`0A1`0300L704d7001Z1`80D0L00`071`0B1`0300L704`7001W1`<0DPL00`071`0B1`0300L704`7
001T1`<0E@L00`071`0C1`0300L704/7001R1`80F0L00`071`0D1`0300L704X7001O1`<0F`L00`07
1`0C1`0300L704X7001M1`80GPL00`071`0D1`0300L704T7001J1`<0H0L00`071`0E1`0300L704P7
001H1`80H`L00`071`0E1`0300L704P7001E1`<0I@L00`071`0F1`0300L704L7001C1`80J0L00`07
1`0G1`0300L704H7001@1`<0JPL00`071`0G1`0300L704H7001>1`80K@L00`071`0H1`0300L704D7
001;1`<0K`L00`071`0I1`0300L704@700191`80LPL00`071`0I1`0300L704@700161`<0M0L00`07
1`0J1`0300L704<700141`80M`L00`071`0K1`0300L7048700111`<0N@L00`071`0K1`0300L70487
000o1`80O0L00`071`0L1`0300L70447000l1`<0OPL00`071`0M1`0300L70407000j1`80P@L00`07
1`0M1`0300L70407000g1`<0P`L00`071`0N1`0300L703l7000e1`80QPL00`071`0O1`0300L703h7
000b1`<0R0L00`071`0O1`0300L703h7000`1`80R`L00`071`0P1`0300L703d7000]1`<0S@L00`07
1`0Q1`0300L703`7000Z1`<0T0L00`071`0Q1`0300L703`7000X1`80T`L00`071`0R1`0300L703/7
000U1`<0UPL00`071`0R1`0300L703X7000S1`80V@L00`071`0R1`0300L703X7000P1`<0V`L00`07
1`0S1`0300L703T7000N1`80WPL00`071`0T1`0300L703P7000K1`<0X0L00`071`0T1`0300L703P7
000I1`80X`L00`071`0U1`0300L703L7000F1`<0Y@L00`071`0V1`0300L703H7000D1`80Z0L00`07
1`0V1`0300L703H7000A1`<0ZPL00`071`0W1`0300L703D7000?1`80[@L00`071`0X1`0300L703@7
000=1`80[`L00`071`0Y1`0300L703<7000=1`80[`L00`071`0Y1`0300L703<7000=1`0300L00:h7
00<01`L0:PL00`071`0b1`003@L010071`2]1`0300L702/700<01`L0<@L000`700<01`L00PL00`07
1`2Z1`0300L702/700<01`L0<@L000`700<01`L00`L00`071`2Y1`0300L702`700<01`L0<0L000`7
00<01`L010L00`071`2X1`0300L702d700<01`L0;`L000`700<01`L01@L00`071`2W1`0300L702d7
00<01`L0;`L000`700<01`L01PL00`071`2V1`0300L702h700<01`L0;PL000`700<01`L01`L00`07
1`2U1`0300L702l700<01`L0;@L000`700<01`L020L00`071`2T1`0300L702l700<01`L0;@L000/7
00<01`L02PL00`071`2S1`0300L7030700<01`L0;0L000/700<01`L02`L00`071`2R1`0300L70347
00<01`L0:`L000/700<01`L030L00`071`2Q1`0300L7034700<01`L0:`L000/700<01`L03@L00`07
1`2Q1`0300L7034700<01`L0:PL000/700<01`L03PL00`071`2P1`0300L7038700<01`L0:@L000/7
00<01`L03`L00`071`031`80VPL00`071`0b1`0300L702T7000;1`0300L7010700<01`L00`L409L7
00<01`L0<`L00`071`0X1`002PL00`071`0B1`8010L20003LP000080T`L00`071`0d1`0300L702L7
000:1`0300L701@700<01`L00`L01@1bN79h00<0T0L00`071`0d1`0300L702L7000:1`0300L701D7
00<01`L00`L01`1bTG:ALY400`2=1`0300L703D700<01`L09PL000X700<01`L05PL00`071`031`80
00MhLWQbN79h00@0R@L00`071`0f1`0300L702D7000:1`0300L701L700<01`L010L02`2ALY5bTG:A
LY5b00<0QPL00`071`0f1`0300L702D7000:1`0300L701P700<01`L010L03@1hLWQbN79hLWQbN780
0`231`0300L703L700<01`L090L000X700<01`L06@L00`071`041`8000ebTG:ALY5bTG:ALY5b00<0
P0L00`071`0h1`0300L702<700091`0300L701/700<01`L01@L0401bN79hLWQbN79hLWQbN78407/7
0P0j1`0300L702<700091`0300L701`700<01`L01@L04`1bTG:ALY5bTG:ALY5bTG:ALY400`1e1`<0
0PL00`071`0h1`0300L7028700091`0300L701d700<01`L01@L2000CN79hLWQbN79hLWQbN79hLWQb
N00306l70`061`0300L703P700<01`L08@L000T700<01`L07PL00`071`061`0F095bTG:ALY5bTG:A
LY5bTG:ALY5bT@@0J0L300T700<01`L0>0L00`071`0Q1`002@L00`071`0O1`0300L700H701T0N79h
LWQbN79hLWQbN79hLWQbN79hLWQb00<0HPL300d700<01`L0>0L00`071`0P1`002@L00`071`0P1`03
00L700H701/0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG800`1L1`<04@L00`071`0h1`0300L701l7
00091`0300L7024700<01`L01PL2000KLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00<0EPL301D7
00<01`L0=`L00`071`0O1`0020L00`071`0S1`0300L700L701h0LY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG8404l70`0H1`0300L703P700<01`L07PL000P700<01`L090L00`071`071`0Q079hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00<0BPL201`700<01`L0>0L00`071`0M1`0020L00`07
1`0U1`0300L700L702<0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@0304@70`0O1`03
00L703L700<01`L07@L000P700<01`L09PL00`071`071`8002=hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN00403d70`0S1`0300L703L700<01`L070L000P700<01`L09`L00`071`081`0W
095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00<0=`L302H700<01`L0>0L00`07
1`0K1`0020L00`071`0X1`0300L700P702T0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLP0303470`0Z1`0300L703L700<01`L06`L000P700<01`L0:@L00`071`081`0[095bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0402X70`0^1`0300L703L700<01`L0
6PL000L700<01`L0:`L00`071`081`8002abN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN0<090L3038700<01`L0=`L00`071`0I1`001`L00`071`0/1`0300L700T702l0LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@0301h70`0f1`0300L703H7
00<01`L06@L000L700<01`L0;@L00`071`091`0a079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN00301P70`0i1`0300L703L700<01`L060L000L700<01`L0;PL00`07
1`091`0c07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00@0
4@L303d700<01`L0=`L00`071`0G1`001`L00`071`0_1`0300L700T70P00=7QbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN78300/70`111`0300L703L700<01`L0
5PL000L700<01`L0<0L00`071`0:1`0g095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALP0300D70`151`0300L703H700<01`L05PL000L700<01`L0<@L00`07
1`0:1`0i07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQb00D0B0L00`071`0g1`0300L701D700061`0300L703<700<01`L02PL0=`2ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG800`000g:A000204L700<01`L0
=`L00`071`0D1`001PL00`071`0d1`0300L700X70P00<G9hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN7800`00279hLWQbN79h0`151`0300L703H700<01`L050L000H7
00<01`L0=@L00`071`0;1`0^07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALP<000ibTG:ALY5bTG:ALY5bT@<0@`L00`071`0f1`0300L701<700061`0300L703H700<01`L0
2`L0:`1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00P00579hLWQbN79h
LWQbN79hLWQbN79h10101`0300L703H700<01`L04PL000H700<01`L0=`L00`071`0;1`0W07:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00<001ZALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALP<0?@L00`071`0f1`0300L7018700061`0300L703P700<01`L02`L2000QN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79h00<0021hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP<0
>`L00`071`0f1`0300L7014700051`0300L703X700<01`L030L07P2ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bT@<002JALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP@0>0L00`07
1`0f1`0300L7010700051`0300L703/700<01`L030L06P1hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
0`00;GQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN00303H700<01`L0
=@L00`071`0@1`001@L00`071`0l1`0300L700`701H0TG:ALY5bTG:ALY5bTG:ALY5bTG:A0`00<i5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@0303<700<01`L0
=PL00`071`0?1`001@L00`071`0m1`803@L04P1hLWQbN79hLWQbN79hLWQbN0<003UhLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00`0a1`0300L703H7
00<01`L03PL000D700<01`L0?`L00`071`0;1`0>095bTG:ALY5bTG:ALY43000oTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00@0;PL00`07
1`0e1`0300L700h700051`0300L7040700<01`L02`L02P1hLWQbN79hLWP30016N79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP<0
;0L00`071`0e1`0300L700d700051`0300L7044700<01`L02`L01P2ALY5bT@<004bALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5b0`0Y1`0300L703H700<01`L030L000@700<01`L0@`L00`071`0:1`03079h00<0059hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQb100V1`0300L703D700<01`L030L000@700<01`L0A0L00`071`091`<0
05VALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@0302@700<01`L0=@L00`071`0;1`0010L00`07
1`151`0300L700D70`021`1M079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00<08PL00`07
1`0e1`0300L700X700041`0300L704H700@01`L70`061`1O07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY400`0P1`0300L703@700<01`L02PL000@700<01`L0A`L300X70640LWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00@070L00`071`0d1`802`L000@700<01`L0A0L30003
1`0700/706@0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0`0J1`0300L70307
0`000`L01`0:1`0010L00`071`111`<01@L00`071`0:1`1V079hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQb0`0H1`0300L702/710041`0300L700T700031`0300L704070P091`03
00L700X706P0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP@05@L00`07
1`0W1`<020L00`071`091`000`L00`071`0m1`<030L00`071`0:1`1[079hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00`0B1`0300L702@70`0;1`0300L700T700031`03
00L703X70`0@1`0300L700X706d0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:A00<040L00`071`0O1`@03`L00`071`081`000`L00`071`0g1`<050L00`071`0:1`1_
079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00@03@L00`07
1`0K1`<04`L00`071`081`000`L00`071`0d1`<060L00`071`0:1`1b07:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0`0;1`0300L701L70`0F1`0300L700P7
00031`0300L703470`0L1`0300L700T707D0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN7800`091`0300L701<70`0I1`0300L700P700031`0300L702h7
0`0P1`0300L700T707L0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALP0300H700<01`L03`L401`700<01`L020L0008700<01`L0;0L302@700<01`L0
2@L0N@1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN78010031`0300L700/70`0P1`0300L700P700021`0300L702T70`0X1`0300L700T707`0TG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
0`000`L01`081`<08`L00`071`081`000PL00`071`0V1`<0;0L00`071`091`1n07QbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h0`041`@0
9PL00`071`081`000PL00`071`0S1`<0<0L00`071`091`1o095bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0502/700<01`L01`L00087
00<01`L080L303@700<01`L02@L0P`1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780LWQb00<0:0L00`071`071`000PL00`071`0M1`<0
>0L00`071`091`25095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALP0202H700<01`L01`L0008700<01`L06PL303`700<01`L0
2@L0O`1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN7801@0X1`0300L700L700000`L01`0I1`<0@0L00`071`091`1l095bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@<0;0L00`07
1`071`0000<700L05PL304@700<01`L02@L0N01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0<00`L00`071`0Y1`0300L700L700000`L01`0D1`80
B0L00`071`081`1d07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG8400L700<01`L0:0L00`071`071`0000<700L04@L304/700<01`L020L0L01bN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN78300`700<01`L09`L00`07
1`071`0000<700L03PL304l700<01`L020L0K01bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALP<040L00`071`0V1`0300L700L700000`L01`0;1`<0D`L00`071`081`1W
079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN00401<700<01`L09`L00`07
1`061`0000<700L020L305L700<01`L020L0H`1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bT@0301P700<01`L09PL00`071`061`0000<01`L01@L305/700<01`L020L0G`1bN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00<070L00`071`0U1`0300L700H700000`071`021`<0
G`L00`071`081`1J07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b100P1`0300L702@700<01`L0
1PL0000300L00080H`L00`071`081`1F079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN78302@700<01`L0
90L00`071`061`000P1W1`0300L700P70540LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40100X1`0300L702<7
00<01`L01PL000031`0706L70P091`1=079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00`0]1`0300L7028700<01`L0
1PL000870P1X1`0300L700L704T0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00<0<@L00`071`0Q1`0300L700H700041`03
00L706H700<01`L01PL0A@1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0403D700<01`L08@L00`071`051`001@L00`071`1V1`03
00L700H70440TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALP0303T700<01`L08@L00`071`051`001PL00`071`1V1`0300L700H703d0N79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00<0
?@L00`071`0P1`0300L700D700071`0300L706H700<01`L01PL0>02ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A10111`0300L701l700<01`L01@L000P7
0P1W1`0300L700H703@0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79h0`161`0300L701h700<01`L01@L000X700<01`L0I@L00`071`061`0`095bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A0`191`0300L701h700<01`L01@L000/7
00<01`L0I@L00`071`061`0[07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LP0404d700<01`L07@L00`071`051`0030L00`071`1U1`0300L700H702P0TG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A0P1B1`0300L701`700<01`L01@L000d70P1V1`0300L700H7
02T0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP02054700<01`L06`L00`07
1`051`003`L00`071`1T1`0300L700H702X0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY4204l700<01`L070L00`071`041`0040L00`071`1T1`0300L700H702/0N79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb0080CPL00`071`0K1`0300L700@7000A1`03
00L706@700<01`L01PL0;02ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
0P1=1`0300L701X700<01`L010L001870P1U1`0300L700D702h0LWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQb0P1<1`0300L701T700<01`L010L001@700<01`L0H`L00`07
1`051`0_07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400`1:1`03
00L701P700<01`L010L001D700<01`L0H`L00`071`041`80031bN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP204P700<01`L060L00`071`041`005PL00`071`1S1`03
00L700<00PL0<P1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
0P171`0300L701L700<01`L010L001L700<01`L0H`L200H703<0LWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00P161`0300L701H700<01`L010L001P70P1S1`03
00L700H703@0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
0P151`0300L701H700<01`L00`L001X700<01`L0H0L00`071`071`0e079hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00`121`0300L701H700<01`L00`L001/7
00<01`L0G`L00`071`081`0g07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bT@02044700<01`L05@L00`071`031`0070L00`071`1N1`0300L700T703P0LWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP80@0L00`07
1`0D1`0300L700<7000M1`80GPL00`071`0:1`0i07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A0080?`L00`071`0C1`0300L700<7000O1`0300L705/7
00<01`L02`L0>P1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN78203h700<01`L04PL00`071`031`0080L00`071`1J1`0300L700/703`0TG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4203`700<01`L0
4PL00`071`031`008@L00`071`1I1`0300L700`703d0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb00<0>PL00`071`0A1`0300L700<7000R1`80
F@L00`071`0=1`0o095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5b0080>@L00`071`0@1`0300L700<7000T1`0300L705H700<01`L03PL0@01h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWP203P700<01`L040L00`071`021`009@L00`071`1E1`0300L700l70440TG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0203H700<01`L0
40L00`071`021`009PL00`071`1D1`0300L701070480N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP203D700<01`L03`L00`071`021`00
9`L00`071`1C1`0300L7014704<0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00<0<`L00`071`0>1`0300L70087000X1`80D`L00`07
1`0B1`1507QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQb0080<PL00`071`0=1`0300L70087000Z1`0300L7050700<01`L04`L0AP2A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY4202L71@041`0300L700d700<01`L00PL002/700<01`L0C`L00`071`0D1`1707QbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN7800P0L1`T000AbN7801PL00`071`0<1`0300L70087000/1`0300L704h700<01`L05@L0B02A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bT@804@L9000<LY5bTG:ALY5bTG8020L00`071`0;1`0300L70087000]1`80CPL00`07
1`0E1`1:079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN78200H72@00579hLWQbN79hLWQbN79hLWQbN7802PL00`071`0;1`03
00L70047000_1`0300L704/700<01`L05PL0B`1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@06000LLY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5b00`700<01`L02PL00`071`011`00<0L00`071`1:1`0300L701L706T0LWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00P0=1`0300L700X700<01`L0
0@L0034700<01`L0B0L00`071`0I1`1X07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bT@0@1`0300L700T700<01`L00@L003870P181`0300L701X706H0LWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN00B1`0300L700P700<01`L00@L003@700<01`L0A@L00`07
1`0K1`1T07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A01@700<01`L01`L00`07
1`011`00=@L00`071`141`0300L701`70200LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP80
041hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWP05@L00`071`071`0300L70047000f1`0300L704<700<01`L07@L0801bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5b0`00?G:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bT@005`L00`071`061`0300L70047000g1`0300L7048700<01`L0
7PL0801bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00PL2000jN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h01T700<01`L01@L00`071`011`00
>0L2048700<01`L07`L0801bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400`L2000gLY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A000K1`0300L700D7
0@011`47000j1`0300L703l700<01`L080L07`1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP00
1@L2000dN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h01d7
00<01`L010L100470@L003/700<01`L0?PL00`071`0Q1`0O07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5b00061`8002mbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LP0201h700<01`L010L100470@L003`700<01`L0?@L00`071`0Q1`0O07QbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79h00081`8002ehLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLP008@L00`071`031`400@L11`00?@L203d700<01`L08PL07`2ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bT@002@L3000YTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00
8`L00`071`021`400@L11`00?`L00`071`0j1`0300L702<701h0N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLP0<1`8002IbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb02D700D01`L7
00021`00@0L00`071`0i1`0300L702@701h0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP0=1`80
02>ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b000V1`0500L71`000PL0044700<01`L0
>0L00`071`0U1`0M07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0003`L2000PLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP0X1`0400L7008700121`80>0L00`071`0V1`8001]bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bT@0040L2000MTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP00:PL01007
1`011`00A0L00`071`0e1`0300L702P70`006G9hLWQbN79hLWQbN79hLWQbN79hLWQbN0004@L2000J
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0/1`0300L0004700151`0300L703@700<01`L0:`L3000F
LY5bTG:ALY5bTG:ALY5bTG:ALY5b01<70`005W:ALY5bTG:ALY5bTG:ALY5bTG:ALP0]1`0300L00047
00161`0300L703<700<01`L0;PL3000DLWQbN79hLWQbN79hLWQbN79hLP0E1`8001=hLWQbN79hLWQb
N79hLWQbN78002l70P011`00A`L00`071`0b1`0300L703470`004G:ALY5bTG:ALY5bTG:ALY4001L7
0P003W:ALY5bTG:ALY5bTG:A0P0`1`800@L004P70P0b1`0300L703@70`003g9hLWQbN79hLWQbN79h
000H1`8000ahLWQbN79hLWQbN00^1`@00`L004X700<01`L0;`L00`071`0g1`@000^ALY5bTG:ALY5b
000J1`8000UbTG:ALY5bT@00:`L400L7001;1`0300L702h700<01`L0>`L30009N79hLWQbN78001/7
0P001WQbN79h02P7100;1`00C0L00`071`0]1`0300L703h70`001Y5bTG:A01d70P000g:A000U1`@0
3`L004d70P0]1`0300L704470`0017QbN00N1`808PL401<7001?1`0300L702X700<01`L0A0L403h7
100G1`00D0L00`071`0Y1`0300L704L70P0i1`@06`L0054700<01`L0:0L00`071`1o1`<07`L00587
0P0X1`0300L707/7100R1`00E0L00`071`0U1`0300L707L7100V1`00E@L00`071`0T1`0300L707<7
100Z1`00EPL00`071`0S1`0300L706l7100^1`00E`L00`071`0R1`0300L706/7100b1`00F0L20287
00<01`L0I`L403H7001J1`0300L701l700<01`L0H`L403X7001K1`0300L701h700<01`L0G`L403h7
001L1`0300L701d700<01`L0G0L30487001M1`807@L00`071`1H1`@0A@L005l700<01`L06PL00`07
1`1D1`@0B@L0060700<01`L06@L00`071`1@1`@0C@L0064700<01`L060L00`071`1<1`@0D@L00687
0P0G1`0300L704T7101E1`00I0L00`071`0D1`0300L704D7101I1`00I@L00`071`0C1`0300L70447
101M1`00IPL00`071`0B1`0300L703h70`1Q1`00I`L00`071`0A1`0300L703X7101T1`00J0L20147
00<01`L0=PL406P7001Z1`0300L700h700<01`L0<PL406`7001[1`0300L700d700<01`L0;PL40707
001/1`0300L700`700<01`L0:PL407@7001]1`8030L00`071`0V1`@0N0L006l700<01`L02@L00`07
1`0R1`@0O0L0070700<01`L020L00`071`0N1`@0P0L0074700<01`L01`L00`071`0K1`<0Q0L00787
0P071`0300L701L710271`00M0L00`071`041`0300L701<7102;1`00M@L00`071`031`0300L700l7
102?1`00MPL00`071`021`0300L700/7102C1`00M`L01@071`L000T7102G1`00N0L200031`0700@7
102K1`00NPL200031`000080W`L007/70P2S1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {259.25, 0}} -> {-0.000245383, 0.0252984, \
0.00329567, 0.00329567}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[14]= "]
}, Open  ]],

Cell["\<\
Polygons embedded in three dimensions are projected onto a plane \
before they are triangulated. This projection might generate \
self\[Dash]intersections, if a polygon is not flat, i.e. if the \
three\[Dash]dimensional points are not in one plane. As a \
self\[Dash]intersecting polygon is not simple, it cannot be triangulated by \
the functions of this package.\
\>", "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
                {
                  StyleBox["GraphicalDebugging",
                    "MR"], 
                  StyleBox["False",
                    
                    "MR"], \(whether\ to\ display\ each\ step\ of\ the\ \
triangulation\ algorithm\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->"SimplePolygonTriangulation:GraphicalDebugging"],

Cell["Option for all triangulation functions of this package.  ", "Caption"],

Cell["\<\
This displays each step of the line\[Dash]sweep algorithm \
decomposing a polygon into montone polygons and of the algorithm to \
triangulate the monotone polygons (see the description in [2]).\
\>", \
"MathCaption"],

Cell[BoxData[
    \(SimplePolygonTriangulation[data2D, 
      GraphicalDebugging -> True]\)], "Input"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
                {
                  StyleBox["PlaneNormal",
                    "MR"], 
                  StyleBox["Automatic",
                    
                    "MR"], \(the\ normal\ vector\ used\ to\ project\ the\ \
three\[Dash]dimensional\ \ points\ onto\ a\ plane\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TradiationalForm]], "Text",
  CellTags->"SimplePolygonTriangulation:PlaneNormal"],

Cell[TextData[{
  "Additional option for ",
  StyleBox["SimplePolygonTriangulation3D", "MR"],
  ". "
}], "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
                {
                  StyleBox["SimplePolygons",
                    "MR"], 
                  StyleBox["All",
                    "MR"], \(the\ polygons\ to\ be\ triangulated\)},
                {
                  StyleBox["TriangleEdges",
                    "MR"], 
                  StyleBox["Automatic",
                    
                    "MR"], \(the\ edges\ of\ triangles\ generated\ by\ the\ \
triangulation\)},
                {
                  StyleBox["QuadrangleQuatering",
                    "MR"], 
                  StyleBox["False",
                    
                    "MR"], \(whether\ to\ triangle\ quadrangles\ by\ \
generating\ four\ triangles\ with\ one\ common\ vertex\ near\ the\ center\ of\
\ the\ quadrangle\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{
  "SimplePolygonTriangulation:SimplePolygons", 
    "SimplePolygonTriangulation:QuadrangleQuatering", 
    "SimplePolygonTriangulation:TriangleEdges"}],

Cell[TextData[{
  "Additional options for ",
  StyleBox["TriangulateSimplePolygons3D", "MR"],
  ". "
}], "Caption"],

Cell[TextData[{
  "A specification of ",
  StyleBox["SimplePolygons->Automatic", "MR"],
  " will only triangulate those ",
  StyleBox["Polygon", "MR"],
  " primitives which have a third argument defining their normal vector, \
which may be set to ",
  StyleBox["Automatic", "MR"],
  ". With ",
  StyleBox["QuadrangleQuatering->True", "MR"],
  " each quadrangle is decomposed into four triangles by generating a new \
vertex near the center of the quadrangle and connecting each of the four \
edges to this new vertex. Setting ",
  StyleBox["TriangleEdges->All", "MR"],
  " will generate triangles without suppressing edges."
}], "Text"],

Cell["This shows all edges of the triangles.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      TriangulateSimplePolygons3D[Graphics3D[Polygon[data3D]], 
        TriangleEdges -> All]]\)], "Input",
  CellLabel->"In[15]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .90377 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.05779 -0.0267649 1.05779 [
[ 0 0 0 0 ]
[ 1 .90377 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04618 .241 m
0 .55492 L
s
0 .55492 m
.42859 .90377 L
s
.42859 .90377 m
.43581 .61967 L
s
.43581 .61967 m
.04618 .241 L
s
.65429 0 m
.96301 .45879 L
s
.96301 .45879 m
1 .75698 L
s
1 .75698 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.04618 .241 m
0 .55492 L
s
0 .55492 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.65429 0 m
.04618 .241 L
s
.43581 .61967 m
.96301 .45879 L
s
.96301 .45879 m
1 .75698 L
s
1 .75698 m
.42859 .90377 L
s
.42859 .90377 m
.43581 .61967 L
s
0 0 m
1 0 L
1 .90377 L
0 .90377 L
closepath
clip
newpath
.5 Mabswid
.28743 .42405 m .57581 .73994 L .57745 .58929 L closepath p .547 .62 .877 r
F P
0 g
s
.57581 .73994 m .65226 .702 L .57745 .58929 L closepath p .547 .62 .877 r
F P
0 g
s
.65226 .702 m .57581 .73994 L .69367 .78112 L closepath p .547 .62 .877 r
F P
0 g
s
.65226 .702 m .7887 .68538 L .57745 .58929 L closepath p .547 .62 .877 r
F P
0 g
s
.7887 .68538 m .65226 .702 L .80495 .77242 L closepath p .547 .62 .877 r
F P
0 g
s
.91454 .67106 m .7887 .68538 L .80495 .77242 L closepath p .547 .62 .877 r
F P
0 g
s
.28743 .42405 m .57745 .58929 L .83321 .51308 L closepath p .547 .62 .877 r
F P
0 g
s
.18377 .34134 m .28743 .42405 L .83321 .51308 L closepath p .547 .62 .877 r
F P
0 g
s
.12229 .29401 m .18377 .34134 L .83321 .51308 L closepath p .547 .62 .877 r
F P
0 g
s
.25 Mabswid
.65429 0 m
.96301 .45879 L
s
.96301 .45879 m
1 .75698 L
s
1 .75698 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.04618 .241 m
0 .55492 L
s
0 .55492 m
.66777 .32676 L
s
.66777 .32676 m
.65429 0 L
s
.65429 0 m
.04618 .241 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{288, 260.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000110P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWH20P492@/K6aZFOP=[GbU]GA^SXj34/
BD53J`00?g=cLda<C2LW9b40<<C4a0X:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm000O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo
_cloocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0
_gl0oglo07lo?gloOglo_gloogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo
_goookl00;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno
_knookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono
0?no?onoOono_onooooo?oooOooo_oGN/lBbShMjHWAdM<;2`W9bLZFUYJNWYg<7iYW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`c
olaV0<aV<laVI/aVVLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lco
I/coVLcoc<coool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI
0?nI<onII_nIVOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<okX70P1T1`00^0L200031`0006<7002e1`<0
0`L206<7002c1`801PL00`07001R1`00/0L300P700@01`L0H@L00:h70P0;1`0400L70647002[1`<0
3@L01@071`L00607002Y1`8040L00`071`021`0300L705d7002V1`<04PL00`071`021`0300L705d7
002T1`805@L00`071`031`0300L705`7002Q1`<05`L00`071`041`0300L705/7002N1`<06PL00`07
1`041`0300L705/7002L1`807PL00`071`041`0300L705X7002I1`<080L00`071`051`0300L705T7
002G1`808`L00`071`051`0300L705T7002D1`<09@L00`071`061`0300L705P7002B1`80:0L00`07
1`071`0300L705L7002?1`<0:PL00`071`071`0300L705L7002=1`80;@L00`071`081`0300L705H7
002:1`<0;`L00`071`091`0300L705D700281`80<PL00`071`091`0300L705D700251`<0=0L00`07
1`0:1`0300L705@700231`80=`L00`071`0;1`0300L705<700201`<0>@L00`071`0<1`0300L70587
001n1`80?0L00`071`0<1`0300L70587001k1`<0?PL00`071`0=1`0300L70547001i1`80@@L00`07
1`0>1`0300L70507001f1`<0@`L00`071`0>1`0300L70507001d1`80APL00`071`0?1`0300L704l7
001a1`<0B0L00`071`0@1`0300L704h7001_1`80B`L00`071`0@1`0300L704h7001/1`<0C@L00`07
1`0A1`0300L704d7001Z1`80D0L00`071`0B1`0300L704`7001W1`<0DPL00`071`0B1`0300L704`7
001T1`<0E@L00`071`0C1`0300L704/7001R1`80F0L00`071`0D1`0300L704X7001O1`<0F`L00`07
1`0C1`0300L704X7001M1`80GPL00`071`0D1`0300L704T7001J1`<0H0L00`071`0E1`0300L704P7
001H1`80H`L00`071`0E1`0300L704P7001E1`<0I@L00`071`0F1`0300L704L7001C1`80J0L00`07
1`0G1`0300L704H7001@1`<0JPL00`071`0G1`0300L704H7001>1`80K@L00`071`0H1`0300L704D7
001;1`<0K`L00`071`0I1`0300L704@700191`80LPL00`071`0I1`0300L704@700161`<0M0L00`07
1`0J1`0300L704<700141`80M`L00`071`0K1`0300L7048700111`<0N@L00`071`0K1`0300L70487
000o1`80O0L00`071`0L1`0300L70447000l1`<0OPL00`071`0M1`0300L70407000j1`80P@L00`07
1`0M1`0300L70407000g1`<0P`L00`071`0N1`0300L703l7000e1`80QPL00`071`0O1`0300L703h7
000b1`<0R0L00`071`0O1`0300L703h7000`1`80R`L00`071`0P1`0300L703d7000]1`<0S@L00`07
1`0Q1`0300L703`7000Z1`<0T0L00`071`0Q1`0300L703`7000X1`80T`L00`071`0R1`0300L703/7
000U1`<0UPL00`071`0R1`0300L703X7000S1`80V@L00`071`0R1`0300L703X7000P1`<0V`L00`07
1`0S1`0300L703T7000N1`80WPL00`071`0T1`0300L703P7000K1`<0X0L00`071`0T1`0300L703P7
000I1`80X`L00`071`0U1`0300L703L7000F1`<0Y@L00`071`0V1`0300L703H7000D1`80Z0L00`07
1`0V1`0300L703H7000A1`<0ZPL00`071`0W1`0300L703D7000?1`80[@L00`071`0X1`0300L703@7
000=1`80[`L00`071`0Y1`0300L703<7000=1`80[`L00`071`0Y1`0300L703<7000=1`0300L00:h7
00<01`L0:PL00`071`0b1`003@L010071`2]1`0300L702/700<01`L0<@L000`700<01`L00PL00`07
1`2Z1`0300L702/700<01`L0<@L000`700<01`L00`L00`071`2Y1`0300L702`700<01`L0<0L000`7
00<01`L010L00`071`2X1`0300L702d700<01`L0;`L000`700<01`L01@L00`071`2W1`0300L702d7
00<01`L0;`L000`700<01`L01PL00`071`2V1`0300L702h700<01`L0;PL000`700<01`L01`L00`07
1`2U1`0300L702l700<01`L0;@L000`700<01`L020L00`071`2T1`0300L702l700<01`L0;@L000/7
00<01`L02PL00`071`2S1`0300L7030700<01`L0;0L000/700<01`L02`L00`071`2R1`0300L70347
00<01`L0:`L000/700<01`L030L00`071`2Q1`0300L7034700<01`L0:`L000/700<01`L03@L00`07
1`2Q1`0300L7034700<01`L0:PL000/700<01`L03PL00`071`2P1`0300L7038700<01`L0:@L000/7
00<01`L03`L00`071`031`80VPL00`071`0b1`0300L702T7000;1`0300L7010700<01`L00`L409L7
00<01`L0<`L00`071`0X1`002PL00`071`0B1`8010L20003LP000080T`L00`071`0d1`0300L702L7
000:1`0300L701@700<01`L00`L01@1bN79h00<0T0L00`071`0d1`0300L702L7000:1`0300L701D7
00<01`L00`L01`1bTG:ALY400`2=1`0300L703D700<01`L09PL000X700<01`L05PL00`071`031`80
00MhLWQbN79h00@0R@L00`071`0f1`0300L702D7000:1`0300L701L700<01`L010L02`2ALY5bTG:A
LY5b00<0QPL00`071`0f1`0300L702D7000:1`0300L701P700<01`L010L03@1hLWQbN79hLWQbN780
0`231`0300L703L700<01`L090L000X700<01`L06@L00`071`041`8000ebTG:ALY5bTG:ALY5b00<0
P0L00`071`0h1`0300L702<700091`0300L701/700<01`L01@L0401bN79hLWQbN79hLWQbN78407/7
0P0j1`0300L702<700091`0300L701`700<01`L01@L04`1bTG:ALY5bTG:ALY5bTG:ALY400`1e1`<0
0PL00`071`0h1`0300L7028700091`0300L701d700<01`L01@L2000CN79hLWQbN79hLWQbN79hLWQb
N00306l70`061`0300L703P700<01`L08@L000T700<01`L07PL00`071`061`0F095bTG:ALY5bTG:A
LY5bTG:ALY5bT@@0J0L300T700<01`L0>0L00`071`0Q1`002@L00`071`0O1`0300L700H70P005g9h
LWQbN79hLWQbN79hLWQbN79hLWQb00<0HPL300d700<01`L0>0L00`071`0P1`002@L00`071`0P1`03
00L700H71@005Y5bTG:ALY5bTG:ALY5bTG:ALY5bTG8305`70`0A1`0300L703P700<01`L07`L000T7
00<01`L08@L00`071`061`8000=bN0000`005G9hLWQbN79hLWQbN79hLWQbN79hLP0305H70`0E1`03
00L703L700<01`L07`L000P700<01`L08`L00`071`071`0607:ALY5b1000595bTG:ALY5bTG:ALY5b
TG:ALY5b101?1`<060L00`071`0h1`0300L701h700081`0300L702@700<01`L01`L02@1bN79hLWQb
N004000DLWQbN79hLWQbN79hLWQbN79hLWP304X70P0L1`0300L703P700<01`L07@L000P700<01`L0
9@L00`071`071`0<07:ALY5bTG:ALY5b0`0057:ALY5bTG:ALY5bTG:ALY5bTG:A0`141`<07`L00`07
1`0g1`0300L701d700081`0300L702H700<01`L01`L2000<N79hLWQbN79hLWQb10004gQbN79hLWQb
N79hLWQbN79hLWP0100m1`<08`L00`071`0g1`0300L701`700081`0300L702L700<01`L020L0402A
LY5bTG:ALY5bTG:ALY44000CLY5bTG:ALY5bTG:ALY5bTG:ALP0303L70`0V1`0300L703P700<01`L0
6`L000P700<01`L0:0L00`071`081`0C07QbN79hLWQbN79hLWQbN79hLP04000BN79hLWQbN79hLWQb
N79hLWQb0`0a1`<0:PL00`071`0g1`0300L701/700081`0300L702T700<01`L020L05P2ALY5bTG:A
LY5bTG:ALY5bTG:ALY44000ALY5bTG:ALY5bTG:ALY5bTG80100Z1`<0;PL00`071`0g1`0300L701X7
00071`0300L702/700<01`L020L2000GLWQbN79hLWQbN79hLWQbN79hLWQbN78010004GQbN79hLWQb
N79hLWQbN79h00<090L3038700<01`L0=`L00`071`0I1`001`L00`071`0/1`0300L700T701/0LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400`004I5bTG:ALY5bTG:ALY5bTG:A00<07PL303H700<01`L0
=PL00`071`0I1`001`L00`071`0]1`0300L700T701d0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N004000@LWQbN79hLWQbN79hLWQbN0<060L303T700<01`L0=`L00`071`0H1`001`L00`071`0^1`03
00L700T70200LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP@000nALY5bTG:ALY5bTG:ALY40
100A1`<0?@L00`071`0g1`0300L701L700071`0300L702l700<01`L02@L2000QN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79h00@000mbN79hLWQbN79hLWQbN7800`0;1`<0@@L00`071`0g1`03
00L701H700071`0300L7030700<01`L02PL09@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG8010003Y5bTG:ALY5bTG:ALY5b0`051`<0A@L00`071`0f1`0300L701H700071`0300L70347
00<01`L02PL0:01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP3000>N79hLWQb
N79hLWQbN78504P700<01`L0=`L00`071`0E1`001PL00`071`0c1`0300L700X702X0TG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY440009LY5bTG:ALY5b00<000=bT@000P171`03
00L703L700<01`L050L000H700<01`L0=0L00`071`0:1`8002]bN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQb00@000=hLP000P00279hLWQbN79h0`151`0300L703H700<01`L0
50L000H700<01`L0=@L00`071`0;1`0^07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALPD000abTG:ALY5bTG:ALY4304<700<01`L0=PL00`071`0C1`001PL00`071`0f1`03
00L700/702/0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h008000EbN79h
LP04000;N79hLWQbN79hLWP010101`0300L703H700<01`L04PL000H700<01`L0=`L00`071`0;1`0W
07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A00<000^ALY5bTG:ALY5bT@04000;
LY5bTG:ALY5bTG800`0m1`0300L703H700<01`L04PL000H700<01`L0>0L00`071`0;1`80025hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00`004WQbN79hLWQbN79hLWQbN79hLP<000]bN79h
LWQbN79hLP0303/700<01`L0=PL00`071`0A1`001@L00`071`0j1`0300L700`701h0TG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY43000HTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b10002Y5bTG:ALY5b
TG8403P700<01`L0=PL00`071`0@1`001@L00`071`0k1`0300L700`710005W9hLWQbN79hLWQbN79h
LWQbN79hLWP3000ON79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN004000:LWQbN79hLWQbN0<0
=PL00`071`0e1`0300L7010700051`0300L703`700<01`L030L20003LP0000@000fALY5bTG:ALY5b
TG:A00<002JALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP@000VALY5bTG:ALY40
0`0c1`0300L703H700<01`L03`L000D700<01`L0?@L200d70`001GQbN79h00H000AbN79h0`00;GQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN0040008LWQbN79hLWP30347
00<01`L0=PL00`071`0>1`001@L00`071`0o1`0300L700/700d0T@00LY5bTG:ALY5b00H003:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<000QbTG:ALY5bT@@0
;PL00`071`0e1`0300L700h700051`0300L7040700<01`L02`L02P1hLP1bN79hLWP30005N79hLWP0
1`00;WQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7840008N79hLWQb
N78302`700<01`L0=@L00`071`0=1`001@L00`071`111`0300L700/700<0TG800P004i40002ALY5b
TG:ALY5bTG:ALY401P00;7:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
10001g:ALY5bTG800`0Y1`0300L703H700<01`L030L000@700<01`L0@`L00`071`0:1`03079h00@0
01MbN79hLWQbN79hLWQbN79hLWQbN79hLP06000ZN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQb10001WQbN79hLP@09PL00`071`0e1`0300L700`700041`0300L704@700<01`L0
2@L30004TG:ALP8001^ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY401`009i5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@040006LY5bTG:A0`0T1`0300L703D700<01`L02`L000@7
00<01`L0A@L00`071`051`<00PL01`1bN79hLWP00P00879hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79h1P009G9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN78010001GQbN79h00<0
8PL00`071`0e1`0300L700X700041`0300L704H700@01`L70`061`0^07:ALY5bTG80LY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALPH002>ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bT@030005TG:ALY400`0P1`0300L703@700<01`L02PL000@700<01`L0A`L300X700P0LWQb
N79hLP8002UhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN006000PLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP40004LWQbN0@070L00`071`0d1`802`L000@700<01`L0
A0L300031`0700/700T0LY5bTG:ALY400P00;G:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALP07000MLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG801000195bTG8301X7
00<01`L0<0L300031`0700X700041`0300L704470`051`0300L700X700X0LWQbN79hLWQb0P00<WQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb1P006gQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN0040003LWQb00<060L00`071`0[1`@010L00`071`091`000`L00`07
1`101`802@L00`071`0:1`1307:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@06000ILY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP040003
TG8000<05@L00`071`0W1`<020L00`071`091`000`L00`071`0m1`<030L00`071`0:1`0;079hLWQb
N79hLWP00P00>g9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQb00L001IbN79hLWQbN79hLWQbN79hLWQbN79h0`000gQbN003018700<01`L090L300/7
00<01`L02@L000<700<01`L0>PL3010700<01`L02PL0301bTG:ALY5bTG:ALP80042ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1P004i5b
TG:ALY5bTG:ALY5bTG:ALY4010000g:A0002010700<01`L07`L400l700<01`L020L000<700<01`L0
=`L301@700<01`L02PL03@1bN79hLWQbN79hLWP00P00A79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h1P004G9hLWQbN79hLWQbN79h
LWQb00@000=h00000P0=1`0300L701/70`0C1`0300L700P700031`0300L703@70`0H1`0300L700X7
05P0LY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b1P003i5bTG:ALY5bTG:ALY5bT@040004LP0000/7
00<01`L05`L301H700<01`L020L000<700<01`L0<@L301`700<01`L02@L03`1hLWQbN79hLWQbN79h
LP02001=N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWP01`0037QbN79hLWQbN79hLPL02@L00`071`0C1`<06@L00`07
1`081`000`L00`071`0^1`<080L00`071`091`0@095bTG:ALY5bTG:ALY5bT@80059bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:A1P002W:ALY5bTG:ALY4600H700<01`L03`L401`700<01`L020L0008700<01`L0
;0L302@700<01`L02@L04@1hLWQbN79hLWQbN79hLWQb008005IhLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLPH000QhLWQbN79hLPH00`L00`071`0;1`<080L00`071`081`000PL00`071`0Y1`<0:0L00`07
1`091`1^095bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY470004
TG:ALPH000<700L020L302<700<01`L020L0008700<01`L09PL302`700<01`L02@L04P1hLWQbN79h
LWQbN79hLWQbN080061bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP60003LWP000@0
10L402H700<01`L020L0008700<01`L08`L3030700<01`L02@L04`2ALY5bTG:ALY5bTG:ALY5bTG80
0P00I95bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG8;02/700<01`L01`L00087
00<01`L080L303@700<01`L02@L0501hLWQbN79hLWQbN79hLWQbN79h0P00J79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h200X1`0300L700L700021`0300L701d70`0h1`03
00L700T701D0TG:ALY5bTG:ALY5bTG:ALY5bTG800P00K95bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5b07:ALP@09PL00`071`071`000PL00`071`0J1`<0?0L00`071`091`1o
07QbN79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLP0502P700<01`L01`L000031`0701T70`101`0300L700T701H0TG:ALY5bTG:ALY5bTG:A
LY5bTG:A0P00I7:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY4302`700<01`L0
1`L000031`0701H70`141`0300L700T701L0N79hLWQbN79hLWQbN79hLWQbN79hLP02001ON79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00`031`0300L702T700<01`L01`L000031`0701@7
0P181`0300L700P701T0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A008005UbTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALP0400L700<01`L0:0L00`071`071`0000<700L04@L304/700<01`L020L0L01b
N79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN78300`700<01`L0
9`L00`071`071`0000<700L03PL304l700<01`L020L06P1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
0P00D95bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0`0@1`0300L702H700<01`L01`L000031`0700/70`1C1`03
00L700P701/0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWP00P00BW9hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h100C1`03
00L702L700<01`L01PL000031`0700P70`1G1`0300L700P701`0LY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5b0P00AI5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@0301P700<01`L09PL00`071`061`0000<01`L01@L305/700<01`L0
20L0G`1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h00<070L00`071`0U1`0300L700H7
00000`071`021`<0G`L00`071`081`0M07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY400P00>g:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00@0
80L00`071`0T1`0300L700H700000`07000206<700<01`L020L07P1bN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLP8003IhLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN78302@700<01`L090L00`071`061`000P1W1`0300L700P701l0LY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:A0080031bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY4402P700<01`L08`L00`071`061`0000<700L0I`L200T704d0LWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N00302d700<01`L08PL00`071`061`000PL206P700<01`L01`L0801bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5b0P009i5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@030347
00<01`L08@L00`071`061`0010L00`071`1V1`0300L700H70280N79hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79h0P008G9hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0403D700<01`L0
8@L00`071`051`001@L00`071`1V1`0300L700H702<0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALP02000LTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP<0>@L00`071`0Q1`0300L700D7
00061`0300L706H700<01`L01PL0901hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN080
01MbN79hLWQbN79hLWQbN79hLWQbN79hLP0303d700<01`L080L00`071`051`001`L00`071`1V1`03
00L700H703P0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:A
LY5bT@@0@@L00`071`0O1`0300L700D700081`80I`L00`071`061`0U07QbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP02000=N79hLWQbN79hLWQbN00304H700<01`L07PL00`071`051`00
2PL00`071`1U1`0300L700H702H0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@80
00QbTG:ALY5bT@<0B@L00`071`0N1`0300L700D7000;1`0300L706D700<01`L01PL09`1hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP020003N78000<0C@L00`071`0M1`0300L700D7
000<1`0300L706D700<01`L01PL0:02ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY42058700<01`L070L00`071`051`003@L206H700<01`L01PL09`1hLWQbN79hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN79hLP04054700<01`L06`L00`071`051`003`L00`071`1T1`0300L700H7
02H0TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@8000AbT@00C`L00`071`0L1`03
00L700@7000@1`0300L706@700<01`L01PL0:`1hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h
LWQbN780LP1bN7800P1>1`0300L701/700<01`L010L0014700<01`L0I0L00`071`061`0/095bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095b07:ALY4204d700<01`L06PL00`071`041`00
4PL206D700<01`L01@L0;P1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN01hLWQb
N78204`700<01`L06@L00`071`041`0050L00`071`1S1`0300L700D702l0LY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@2ALY40TG:ALY5bT@0304X700<01`L060L00`071`041`005@L00`07
1`1S1`0300L700@70P00<79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79h07QbN79h
LWQbN080B0L00`071`0H1`0300L700@7000F1`0300L706<700<01`L00`021`0b07:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG80LY5bTG:ALY5bTG8204L700<01`L05`L00`071`041`00
5`L00`071`1S1`801PL0<`1bN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb079hLWQb079hLWQb
N79hLWQbN00204H700<01`L05PL00`071`041`0060L206<700<01`L01PL0=01bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY40TG:ALY5b07:ALY5bTG:ALY5bTG8204D700<01`L05PL00`071`031`00
6PL00`071`1P1`0300L700L703D0LWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN780LWQbN79h07Qb
N79hLWQbN79hLWQbN003048700<01`L05PL00`071`031`006`L00`071`1O1`0300L700P703L0LY5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:A0080@@L00`07
1`0E1`0300L700<7000L1`0300L705h700<01`L02@L0>01bN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N780LWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQb0P101`0300L701@700<01`L00`L001d70P1N1`03
00L700X703T0LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG80LY5bTG:ALY5bTG:ALY5b
TG:ALY400P0o1`0300L701<700<01`L00`L001l700<01`L0F`L00`071`0;1`0j079hLWQbN79hLWQb
N79hLWQbN79hLWQbN780LWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLP80?PL00`071`0B1`03
00L700<7000P1`0300L705X700<01`L02`L0?02ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:A
LY5bTG80LY5bTG:ALY5bTG:ALY5bTG:ALY5bT@80?0L00`071`0B1`0300L700<7000Q1`0300L705T7
00<01`L030L0?@1hLWQbN79hLWQbN79hLWQbN79hLWQbN780LWQbN79hLWQbN01hLWQbN79hLWQbN79h
LWQbN79hLWQbN7800`0j1`0300L7014700<01`L00`L002870P1I1`0300L700d703l0TG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG800P0i1`03
00L7010700<01`L00`L002@700<01`L0EPL00`071`0>1`1007QbN79hLWQbN79hLWQbN79hLWQbN780
LWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN080>0L00`071`0@1`0300L70087
000U1`0300L705D700<01`L03`L0@@2ALY5bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5b07:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b0080=PL00`071`0@1`0300L70087000V1`0300L705@7
00<01`L040L0@P1hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQb079hLWQbN79hLWQbN79h
LWQbN79hLWQbN79hLWQbN080=@L00`071`0?1`0300L70087000W1`0300L705<700<01`L04@L0@`2A
LY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5b07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
LY5bTG800`0c1`0300L700h700<01`L00PL002P70P1C1`0300L7018704D0N79hLWQbN79hLWQbN79h
LWQb079hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN7800P0b1`03
00L700d700<01`L00PL002X700<01`L0D0L00`071`0C1`16095bTG:ALY5bTG:ALY5bTG:A095bTG:A
LY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@809`L500@700<01`L0
3@L00`071`021`00:`L00`071`1?1`0300L701@704L0N79hLWQbN79hLWQbN79hLP1bN79hLWQbN79h
LWQbN79h07QbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP0201`72@00179hLP061`03
00L700`700<01`L00PL002`700<01`L0CPL00`071`0E1`18095bTG:ALY5bTG:ALY5bT@2ALY5bTG:A
LY5bTG:ALY5b07:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A0P0A1`T000abTG:A
LY5bTG:ALP081`0300L700/700<01`L00PL002d70P1>1`0300L701D704X0LWQbN79hLWQbN79hLWQb
079hLWQbN79hLWQbN79hLWQb079hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP80
1PL9000DLWQbN79hLWQbN79hLWQbN79hLP0:1`0300L700/700<01`L00@L002l700<01`L0B`L00`07
1`0F1`1907:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5b
TG:ALY5bTG:ALY5bTG:ALY5bT@08000LLY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5b00`700<01`L0
2PL00`071`011`00<0L00`071`1:1`0300L701L70400LWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQb
N79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb20008GQbN01hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLWQbN00200d700<01`L02PL00`071`011`00<@L00`071`181`0300L701T703L0LY5b
TG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5bTG:A00P002UbTG:A
LY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A000@1`0300L700T700<01`L00@L00387
0P181`0300L701X702h0LWQbN79hLWQbN780LWQbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQb
2000<7QbN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79hLWQbN79hLWQbN79hLWQbN79h018700<01`L0
20L00`071`011`00=0L00`071`151`0300L701/702D0LY5bTG:ALY5bT@2ALY5bTG:ALY5bTG:ALY5b
TG:ALP1bTG:A00P003MbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:A
LY5bTG:ALY4001@700<01`L01`L00`071`011`00=@L00`071`141`0300L701`701l0LWQbN79hLWQb
079hLWQbN79hLWQbN79hLWQbN79h00D003ihLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQb
N780LWQbN79hLWQbN79hLWQbN79hLWQbN79h01D700<01`L01`L00`071`011`00=PL00`071`131`03
00L701d701`0LY5bTG:ALY40TG:ALY5bTG:ALY5bTG:ALY5b0P000i5b0002000mLY5bTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A095bTG:ALY5bTG:ALY5bTG:ALY5bTG:A000G1`0300L700H7
00<01`L00@L003L700<01`L0@PL00`071`0N1`0I079hLWQbN780LWQbN79hLWQbN79hLWQbN0020005
LWQbN0000PL2000jN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLWQbN79hLP1bN79hLWQbN79hLWQb
N79hLWQbN79h01T700<01`L01@L00`071`011`00>0L2048700<01`L07`L05P1bTG:ALY40TG:ALY5b
TG:ALY5bTG820008TG:ALY5bT@031`8003MbTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bT@2A
LY5bTG:ALY5bTG:ALY5bTG:ALY4001/700<01`L01@L100470@L003X700<01`L0?`L00`071`0P1`0C
079hLWQb079hLWQbN79hLWQbN002000:LWQbN79hLWQb00D70P00=7QbN79hLWQbN79hLWQbN79hLWQb
N79hLWQbN79hLP1bN79hLWQbN79hLWQbN79hLWQbN00M1`0300L700@70@011`47000k1`0300L703h7
00<01`L08@L0401bTG:A095bTG:ALY5bTG82000=TG:ALY5bTG:ALY5b00061`8002mbTG:ALY5bTG:A
LY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG:ALP0201h700<01`L010L100470@L003`7
00<01`L0?@L00`071`0Q1`0>07QbN780LWQbN79hLWP2000?LWQbN79hLWQbN79hLWP000P70P00;GQb
N79hLWQbN79hLWQbN79hLWQbN79hLWQbN01hLWQbN79hLWQbN79hLWQb000Q1`0300L700<70@011`47
000m1`80?@L00`071`0R1`0;095bT@2ALY5bTG800P004Y5bTG:ALY5bTG:ALY5bTG:A00T70`00:I5b
TG:ALY5bTG:ALY5bTG:ALY5bTG:ALP1bTG:ALY5bTG:ALY5bTG8002<700<01`L00PL100470@L003l7
00<01`L0>PL00`071`0S1`0807Qb079hLWP2000DLWQbN79hLWQbN79hLWQbN79hLP0<1`8002IbN79h
LWQbN79hLWQbN79hLWQbN79h07QbN79hLWQbN79hLWQb02D700D01`L700021`00@0L00`071`0i1`03
00L702@700D0T@2ALP02000GTG:ALY5bTG:ALY5bTG:ALY5bTG:ALP003@L2000STG:ALY5bTG:ALY5b
TG:ALY5bTG80LY5bTG:ALY5bTG:ALP009PL01@071`L0008700111`0300L703P700<01`L09@L4000I
LWQbN79hLWQbN79hLWQbN79hLWQbN79h000?1`80021bN79hLWQbN79hLWQbN79hLWP0N79hLWQbN79h
LWQb02P700@01`L00PL004870P0h1`0300L702H70P006g:ALY5bTG:ALY5bTG:ALY5bTG:ALY5bTG:A
000@1`8001fALY5bTG:ALY5bTG:ALY5bT@2ALY5bTG:ALY5b000Z1`0400L7004700141`0300L703D7
00<01`L0:0L3000ILWQbN79hLWQbN79hLWQbN79hLWQbN79h000A1`8001YbN79hLWQbN79hLWQbN780
LWQbN79hLWQb02`700<01`000@L004D700<01`L0=0L00`071`0[1`<001IbTG:ALY5bTG:ALY5bTG:A
LY5bTG804`L3000FLY5bTG:ALY5bTG:A095bTG:ALY5b02d700<01`000@L004H700<01`L0<`L00`07
1`0^1`<001AbN79hLWQbN79hLWQbN79hLWQb01D70P004gQbN79hLWQbN780LWQbN79hLP00;`L20047
00171`0300L7038700<01`L0<@L3000ALY5bTG:ALY5bTG:ALY5bT@005`L2000>LY5bTG:ALY40TG:A
LY4203070P011`00B0L2038700<01`L0=0L3000?LWQbN79hLWQbN79hLWP001P70P0037QbN79hLP1b
N79h02h710031`00BPL00`071`0_1`0300L703L710002i5bTG:ALY5bTG8001X70P002G:ALY5b07:A
000[1`@01`L004/700<01`L0;PL00`071`0k1`<000UhLWQbN79hLP006`L20006N79h07P0:0L400/7
001<1`0300L702d700<01`L0?PL30006TG:ALY407@L20003LP0002D7100?1`00C@L202d700<01`L0
@@L30004N79h01h70P0R1`@04`L004l700<01`L0:PL00`071`141`@0?PL401L7001@1`0300L702T7
00<01`L0A`L203T7100K1`00D@L00`071`0X1`0300L707l70`0O1`00DPL202P700<01`L0N`L40287
001D1`0300L702D700<01`L0M`L402H7001E1`0300L702@700<01`L0L`L402X7001F1`0300L702<7
00<01`L0K`L402h7001G1`0300L7028700<01`L0J`L40387001H1`808PL00`071`1W1`@0=PL005X7
00<01`L07`L00`071`1S1`@0>PL005/700<01`L07PL00`071`1O1`@0?PL005`700<01`L07@L00`07
1`1L1`<0@PL005d70P0M1`0300L705P710151`00G`L00`071`0J1`0300L705@710191`00H0L00`07
1`0I1`0300L70507101=1`00H@L00`071`0H1`0300L704`7101A1`00HPL201L700<01`L0B@L405D7
001T1`0300L701@700<01`L0A@L405T7001U1`0300L701<700<01`L0@@L405d7001V1`0300L70187
00<01`L0?PL30647001W1`0300L7014700<01`L0>PL406@7001X1`804@L00`071`0f1`@0J0L006X7
00<01`L03PL00`071`0b1`@0K0L006/700<01`L03@L00`071`0^1`@0L0L006`700<01`L030L00`07
1`0Z1`@0M0L006d70P0<1`0300L702H7101h1`00K`L00`071`091`0300L70287101l1`00L0L00`07
1`081`0300L701h710201`00L@L00`071`071`0300L701/70`241`00LPL200L700<01`L05`L408L7
001d1`0300L700@700<01`L04`L408/7001e1`0300L700<700<01`L03`L408l7001f1`0300L70087
00<01`L02`L409<7001g1`0500L71`002@L409L7001h1`8000<700L010L409/7001j1`8000<70000
0P2O1`00N`L20:<70000\
\>"],
  ImageRangeCache->{{{0, 287}, {259.25, 0}} -> {-0.000245383, 0.0252984, \
0.00329567, 0.00329567}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note:", "TB"],
  " For further information about the ",
  StyleBox["SimplePolygonTriangulation", "MR"],
  " packge and the latest release of this package you may contact the author \
electronically at Martin_Kraus_Germany@yahoo.com."
}], "Text"],

Cell["References", "Subsubsection",
  CellTags->{"S5.3.1", "1.28"}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[InvisibleSpace]\)\([1]\)\)\)], 
    "InlineFormula"],
  " ",
  StyleBox["Mathematica Graphics: Techniques and Applications", "TI"],
  ", Tom Wickham-Jones, TELOS/Springer\[Dash]Verlag, 1994.\n[2] ",
  StyleBox["Computational Geometry in C", "IT"],
  ", Joseph O'Rourke, Cambridge University Press, 1994."
}], "Text"]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{746, 850},
WindowMargins->{{18, Automatic}, {10, Automatic}},
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SimplePolygonTriangulation:SimplePolygonTriangulation"->{
    Cell[2311, 62, 5449, 132, 157, "Text",
      CellTags->{
      "SimplePolygonTriangulation:SimplePolygonTriangulation", 
        "SimplePolygonTriangulation:SimplePolygonTriangulation3D", 
        "SimplePolygonTriangulation:TriangulateSimplePolygons", 
        "SimplePolygonTriangulation:TriangulateSimplePolygons3D"}]},
  "SimplePolygonTriangulation:SimplePolygonTriangulation3D"->{
    Cell[2311, 62, 5449, 132, 157, "Text",
      CellTags->{
      "SimplePolygonTriangulation:SimplePolygonTriangulation", 
        "SimplePolygonTriangulation:SimplePolygonTriangulation3D", 
        "SimplePolygonTriangulation:TriangulateSimplePolygons", 
        "SimplePolygonTriangulation:TriangulateSimplePolygons3D"}]},
  "SimplePolygonTriangulation:TriangulateSimplePolygons"->{
    Cell[2311, 62, 5449, 132, 157, "Text",
      CellTags->{
      "SimplePolygonTriangulation:SimplePolygonTriangulation", 
        "SimplePolygonTriangulation:SimplePolygonTriangulation3D", 
        "SimplePolygonTriangulation:TriangulateSimplePolygons", 
        "SimplePolygonTriangulation:TriangulateSimplePolygons3D"}]},
  "SimplePolygonTriangulation:TriangulateSimplePolygons3D"->{
    Cell[2311, 62, 5449, 132, 157, "Text",
      CellTags->{
      "SimplePolygonTriangulation:SimplePolygonTriangulation", 
        "SimplePolygonTriangulation:SimplePolygonTriangulation3D", 
        "SimplePolygonTriangulation:TriangulateSimplePolygons", 
        "SimplePolygonTriangulation:TriangulateSimplePolygons3D"}]},
  "SimplePolygonTriangulation:GraphicalDebugging"->{
    Cell[124903, 2388, 770, 19, 81, "Text",
      CellTags->"SimplePolygonTriangulation:GraphicalDebugging"]},
  "SimplePolygonTriangulation:PlaneNormal"->{
    Cell[126089, 2422, 788, 19, 79, "Text",
      CellTags->"SimplePolygonTriangulation:PlaneNormal"]},
  "SimplePolygonTriangulation:SimplePolygons"->{
    Cell[126998, 2449, 1386, 35, 155, "Text",
      CellTags->{
      "SimplePolygonTriangulation:SimplePolygons", 
        "SimplePolygonTriangulation:QuadrangleQuatering", 
        "SimplePolygonTriangulation:TriangleEdges"}]},
  "SimplePolygonTriangulation:QuadrangleQuatering"->{
    Cell[126998, 2449, 1386, 35, 155, "Text",
      CellTags->{
      "SimplePolygonTriangulation:SimplePolygons", 
        "SimplePolygonTriangulation:QuadrangleQuatering", 
        "SimplePolygonTriangulation:TriangleEdges"}]},
  "SimplePolygonTriangulation:TriangleEdges"->{
    Cell[126998, 2449, 1386, 35, 155, "Text",
      CellTags->{
      "SimplePolygonTriangulation:SimplePolygons", 
        "SimplePolygonTriangulation:QuadrangleQuatering", 
        "SimplePolygonTriangulation:TriangleEdges"}]},
  "S5.3.1"->{
    Cell[157683, 3008, 67, 1, 34, "Subsubsection",
      CellTags->{"S5.3.1", "1.28"}]},
  "1.28"->{
    Cell[157683, 3008, 67, 1, 34, "Subsubsection",
      CellTags->{"S5.3.1", "1.28"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SimplePolygonTriangulation:SimplePolygonTriangulation", 158808, 3039},
  {"SimplePolygonTriangulation:SimplePolygonTriangulation3D", 159198, 3046},
  {"SimplePolygonTriangulation:TriangulateSimplePolygons", 159585, 3053},
  {"SimplePolygonTriangulation:TriangulateSimplePolygons3D", 159974, 3060},
  {"SimplePolygonTriangulation:GraphicalDebugging", 160354, 3067},
  {"SimplePolygonTriangulation:PlaneNormal", 160511, 3070},
  {"SimplePolygonTriangulation:SimplePolygons", 160664, 3073},
  {"SimplePolygonTriangulation:QuadrangleQuatering", 160948, 3079},
  {"SimplePolygonTriangulation:TriangleEdges", 161226, 3085},
  {"S5.3.1", 161470, 3091},
  {"1.28", 161571, 3094}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 70, 0, 40, "Subsection"],
Cell[1790, 51, 518, 9, 72, "Text"],
Cell[2311, 62, 5449, 132, 157, "Text",
  CellTags->{
  "SimplePolygonTriangulation:SimplePolygonTriangulation", 
    "SimplePolygonTriangulation:SimplePolygonTriangulation3D", 
    "SimplePolygonTriangulation:TriangulateSimplePolygons", 
    "SimplePolygonTriangulation:TriangulateSimplePolygons3D"}],
Cell[7763, 196, 59, 0, 16, "Caption"],
Cell[7825, 198, 294, 7, 40, "Text"],
Cell[8122, 207, 46, 0, 30, "MathCaption"],
Cell[8171, 209, 109, 2, 26, "Input"],
Cell[8283, 213, 61, 0, 30, "MathCaption"],
Cell[8347, 215, 232, 4, 42, "Input"],
Cell[8582, 221, 73, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[8680, 225, 89, 2, 26, "Input"],
Cell[8772, 229, 4207, 96, 184, 783, 49, "GraphicsData", "PostScript", \
"Graphics"],
Cell[12982, 327, 155, 4, 21, "Output"]
}, Open  ]],
Cell[13152, 334, 52, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[13229, 338, 101, 2, 26, "Input"],
Cell[13333, 342, 172, 3, 37, "Output"]
}, Open  ]],
Cell[13520, 348, 77, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[13622, 352, 103, 2, 26, "Input"],
Cell[13728, 356, 537, 8, 85, "Output"]
}, Open  ]],
Cell[14280, 367, 61, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[14366, 371, 131, 4, 26, "Input"],
Cell[14500, 377, 14081, 246, 184, 1142, 81, "GraphicsData", "PostScript", \
"Graphics"],
Cell[28584, 625, 155, 4, 21, "Output"]
}, Open  ]],
Cell[28754, 632, 250, 7, 46, "MathCaption"],

Cell[CellGroupData[{
Cell[29029, 643, 137, 3, 26, "Input"],
Cell[29169, 648, 4420, 120, 184, 1047, 73, "GraphicsData", "PostScript", \
"Graphics"],
Cell[33592, 770, 155, 4, 21, "Output"]
}, Open  ]],
Cell[33762, 777, 103, 4, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[33890, 785, 82, 2, 26, "Input"],
Cell[33975, 789, 538, 11, 172, "Output"]
}, Open  ]],
Cell[34528, 803, 234, 7, 40, "Text"],
Cell[34765, 812, 209, 8, 30, "MathCaption"],
Cell[34977, 822, 160, 4, 26, "Input"],
Cell[35140, 828, 123, 3, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[35288, 835, 92, 2, 26, "Input"],
Cell[35383, 839, 31126, 513, 264, 2051, 149, "GraphicsData", "PostScript", \
"Graphics"],
Cell[66512, 1354, 158, 4, 21, "Output"]
}, Open  ]],
Cell[66685, 1361, 52, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[66762, 1365, 106, 2, 26, "Input"],
Cell[66871, 1369, 173, 3, 37, "Output"]
}, Open  ]],
Cell[67059, 1375, 77, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[67161, 1379, 108, 2, 26, "Input"],
Cell[67272, 1383, 850, 12, 149, "Output"]
}, Open  ]],
Cell[68137, 1398, 61, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[68223, 1402, 110, 2, 26, "Input"],
Cell[68336, 1406, 27841, 472, 267, 2111, 149, "GraphicsData", "PostScript", \
"Graphics"],
Cell[96180, 1880, 158, 4, 21, "Output"]
}, Open  ]],
Cell[96353, 1887, 163, 6, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[96541, 1897, 128, 3, 26, "Input"],
Cell[96672, 1902, 27664, 468, 267, 1995, 146, "GraphicsData", "PostScript", \
"Graphics"],
Cell[124339, 2372, 158, 4, 21, "Output"]
}, Open  ]],
Cell[124512, 2379, 388, 7, 56, "Text"],
Cell[124903, 2388, 770, 19, 81, "Text",
  CellTags->"SimplePolygonTriangulation:GraphicalDebugging"],
Cell[125676, 2409, 76, 0, 16, "Caption"],
Cell[125755, 2411, 226, 5, 46, "MathCaption"],
Cell[125984, 2418, 102, 2, 26, "Input"],
Cell[126089, 2422, 788, 19, 79, "Text",
  CellTags->"SimplePolygonTriangulation:PlaneNormal"],
Cell[126880, 2443, 115, 4, 16, "Caption"],
Cell[126998, 2449, 1386, 35, 155, "Text",
  CellTags->{
  "SimplePolygonTriangulation:SimplePolygons", 
    "SimplePolygonTriangulation:QuadrangleQuatering", 
    "SimplePolygonTriangulation:TriangleEdges"}],
Cell[128387, 2486, 115, 4, 16, "Caption"],
Cell[128505, 2492, 636, 15, 72, "Text"],
Cell[129144, 2509, 61, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[129230, 2513, 158, 4, 26, "Input"],
Cell[129391, 2519, 27841, 472, 267, 2111, 149, "GraphicsData", "PostScript", \
"Graphics"],
Cell[157235, 2993, 157, 4, 21, "Output"]
}, Open  ]],
Cell[157407, 3000, 273, 6, 40, "Text"],
Cell[157683, 3008, 67, 1, 34, "Subsubsection",
  CellTags->{"S5.3.1", "1.28"}],
Cell[157753, 3011, 379, 9, 48, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

